@@ -33,7 +33,7 @@ public final class ScriptAlertChannel implements AlertChannel {
         AlertData alertData = alertinfo.getAlertData();
         Map<String, String> paramsMap = alertinfo.getAlertParams();
         if (MapUtils.isEmpty(paramsMap)) {
-            return new AlertResult("false", "script params is empty");
+            return new AlertResult(false, "script params is empty");
         }
         return new ScriptSender(paramsMap).sendScriptAlert(alertData.getTitle(), alertData.getContent());
     }
