@@ -24,15 +24,18 @@ import static org.apache.dolphinscheduler.api.enums.Status.QUERY_ACCESSTOKEN_BY_
 import static org.apache.dolphinscheduler.api.enums.Status.QUERY_ACCESSTOKEN_LIST_PAGING_ERROR;
 import static org.apache.dolphinscheduler.api.enums.Status.UPDATE_ACCESS_TOKEN_ERROR;
 
-import org.apache.dolphinscheduler.api.aspect.AccessLogAnnotation;
+import org.apache.dolphinscheduler.api.audit.OperatorLog;
+import org.apache.dolphinscheduler.api.audit.enums.AuditType;
 import org.apache.dolphinscheduler.api.exceptions.ApiException;
 import org.apache.dolphinscheduler.api.service.AccessTokenService;
+import org.apache.dolphinscheduler.api.utils.PageInfo;
 import org.apache.dolphinscheduler.api.utils.Result;
 import org.apache.dolphinscheduler.common.constants.Constants;
+import org.apache.dolphinscheduler.dao.entity.AccessToken;
 import org.apache.dolphinscheduler.dao.entity.User;
 import org.apache.dolphinscheduler.plugin.task.api.utils.ParameterUtils;
 
-import java.util.Map;
+import java.util.List;
 
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.http.HttpStatus;
@@ -82,13 +85,14 @@ public class AccessTokenController extends BaseController {
     @PostMapping()
     @ResponseStatus(HttpStatus.CREATED)
     @ApiException(CREATE_ACCESS_TOKEN_ERROR)
-    @AccessLogAnnotation(ignoreRequestArgs = "loginUser")
-    public Result createToken(@Parameter(hidden = true) @RequestAttribute(value = Constants.SESSION_USER) User loginUser,
-                              @RequestParam(value = "userId") int userId,
-                              @RequestParam(value = "expireTime") String expireTime,
-                              @RequestParam(value = "token", required = false) String token) {
+    @OperatorLog(auditType = AuditType.TOKEN_CREATE)
+    public Result<AccessToken> createToken(@Parameter(hidden = true) @RequestAttribute(value = Constants.SESSION_USER) User loginUser,
+                                           @RequestParam(value = "userId") int userId,
+                                           @RequestParam(value = "expireTime") String expireTime,
+                                           @RequestParam(value = "token", required = false) String token) {
 
-        return accessTokenService.createToken(loginUser, userId, expireTime, token);
+        AccessToken accessToken = accessTokenService.createToken(loginUser, userId, expireTime, token);
+        return Result.success(accessToken);
     }
 
     /**
@@ -103,12 +107,11 @@ public class AccessTokenController extends BaseController {
     @PostMapping(value = "/generate")
     @ResponseStatus(HttpStatus.CREATED)
     @ApiException(GENERATE_TOKEN_ERROR)
-    @AccessLogAnnotation(ignoreRequestArgs = "loginUser")
-    public Result generateToken(@RequestAttribute(value = Constants.SESSION_USER) User loginUser,
-                                @RequestParam(value = "userId") int userId,
-                                @RequestParam(value = "expireTime") String expireTime) {
-        Map<String, Object> result = accessTokenService.generateToken(loginUser, userId, expireTime);
-        return returnDataList(result);
+    public Result<String> generateToken(@RequestAttribute(value = Constants.SESSION_USER) User loginUser,
+                                        @RequestParam(value = "userId") int userId,
+                                        @RequestParam(value = "expireTime") String expireTime) {
+        String token = accessTokenService.generateToken(loginUser, userId, expireTime);
+        return Result.success(token);
     }
 
     /**
@@ -129,19 +132,16 @@ public class AccessTokenController extends BaseController {
     @GetMapping()
     @ResponseStatus(HttpStatus.OK)
     @ApiException(QUERY_ACCESSTOKEN_LIST_PAGING_ERROR)
-    @AccessLogAnnotation(ignoreRequestArgs = "loginUser")
-    public Result queryAccessTokenList(@Parameter(hidden = true) @RequestAttribute(value = Constants.SESSION_USER) User loginUser,
-                                       @RequestParam("pageNo") Integer pageNo,
-                                       @RequestParam(value = "searchVal", required = false) String searchVal,
-                                       @RequestParam("pageSize") Integer pageSize) {
+    public Result<PageInfo<AccessToken>> queryAccessTokenList(@Parameter(hidden = true) @RequestAttribute(value = Constants.SESSION_USER) User loginUser,
+                                                              @RequestParam("pageNo") Integer pageNo,
+                                                              @RequestParam(value = "searchVal", required = false) String searchVal,
+                                                              @RequestParam("pageSize") Integer pageSize) {
 
-        Result result = checkPageParams(pageNo, pageSize);
-        if (!result.checkResult()) {
-            return result;
-        }
+        checkPageParams(pageNo, pageSize);
         searchVal = ParameterUtils.handleEscapes(searchVal);
-        result = accessTokenService.queryAccessTokenList(loginUser, searchVal, pageNo, pageSize);
-        return result;
+        PageInfo<AccessToken> accessTokenPageInfo =
+                accessTokenService.queryAccessTokenList(loginUser, searchVal, pageNo, pageSize);
+        return Result.success(accessTokenPageInfo);
     }
 
     /**
@@ -158,11 +158,10 @@ public class AccessTokenController extends BaseController {
     @GetMapping(value = "/user/{userId}")
     @ResponseStatus(HttpStatus.OK)
     @ApiException(QUERY_ACCESSTOKEN_BY_USER_ERROR)
-    @AccessLogAnnotation(ignoreRequestArgs = "loginUser")
-    public Result queryAccessTokenByUser(@Parameter(hidden = true) @RequestAttribute(value = Constants.SESSION_USER) User loginUser,
-                                         @PathVariable("userId") Integer userId) {
-        Map<String, Object> result = this.accessTokenService.queryAccessTokenByUser(loginUser, userId);
-        return this.returnDataList(result);
+    public Result<List<AccessToken>> queryAccessTokenByUser(@Parameter(hidden = true) @RequestAttribute(value = Constants.SESSION_USER) User loginUser,
+                                                            @PathVariable("userId") Integer userId) {
+        List<AccessToken> accessTokens = accessTokenService.queryAccessTokenByUser(loginUser, userId);
+        return Result.success(accessTokens);
     }
 
     /**
@@ -173,14 +172,15 @@ public class AccessTokenController extends BaseController {
      * @return delete result code
      */
     @Parameter(hidden = true)
+    @Operation(summary = "deleteToken", description = "DELETE_TOKEN_NOTES")
     @DeleteMapping(value = "/{id}")
     @ResponseStatus(HttpStatus.OK)
     @ApiException(DELETE_ACCESS_TOKEN_ERROR)
-    @AccessLogAnnotation(ignoreRequestArgs = "loginUser")
-    public Result delAccessTokenById(@Parameter(hidden = true) @RequestAttribute(value = Constants.SESSION_USER) User loginUser,
-                                     @PathVariable(value = "id") int id) {
-        Map<String, Object> result = accessTokenService.delAccessTokenById(loginUser, id);
-        return returnDataList(result);
+    @OperatorLog(auditType = AuditType.TOKEN_DELETE)
+    public Result<Boolean> delAccessTokenById(@Parameter(hidden = true) @RequestAttribute(value = Constants.SESSION_USER) User loginUser,
+                                              @PathVariable(value = "id") int id) {
+        accessTokenService.deleteAccessTokenById(loginUser, id);
+        return Result.success(false);
     }
 
     /**
@@ -203,15 +203,15 @@ public class AccessTokenController extends BaseController {
     @PutMapping(value = "/{id}")
     @ResponseStatus(HttpStatus.OK)
     @ApiException(UPDATE_ACCESS_TOKEN_ERROR)
-    @AccessLogAnnotation(ignoreRequestArgs = "loginUser")
-    public Result updateToken(@Parameter(hidden = true) @RequestAttribute(value = Constants.SESSION_USER) User loginUser,
-                              @PathVariable(value = "id") int id,
-                              @RequestParam(value = "userId") int userId,
-                              @RequestParam(value = "expireTime") String expireTime,
-                              @RequestParam(value = "token", required = false) String token) {
+    @OperatorLog(auditType = AuditType.TOKEN_UPDATE)
+    public Result<AccessToken> updateToken(@Parameter(hidden = true) @RequestAttribute(value = Constants.SESSION_USER) User loginUser,
+                                           @PathVariable(value = "id") int id,
+                                           @RequestParam(value = "userId") int userId,
+                                           @RequestParam(value = "expireTime") String expireTime,
+                                           @RequestParam(value = "token", required = false) String token) {
 
-        Map<String, Object> result = accessTokenService.updateToken(loginUser, id, userId, expireTime, token);
-        return returnDataList(result);
+        AccessToken accessToken = accessTokenService.updateToken(loginUser, id, userId, expireTime, token);
+        return Result.success(accessToken);
     }
 
 }
