@@ -22,11 +22,14 @@ import static org.apache.dolphinscheduler.api.enums.Status.NOT_SUPPORT_SSO;
 import static org.apache.dolphinscheduler.api.enums.Status.SIGN_OUT_ERROR;
 import static org.apache.dolphinscheduler.api.enums.Status.USER_LOGIN_FAILURE;
 
+import org.apache.dolphinscheduler.api.configuration.ApiConfig;
 import org.apache.dolphinscheduler.api.configuration.OAuth2Configuration;
 import org.apache.dolphinscheduler.api.enums.Status;
 import org.apache.dolphinscheduler.api.exceptions.ApiException;
 import org.apache.dolphinscheduler.api.security.Authenticator;
 import org.apache.dolphinscheduler.api.security.impl.AbstractSsoAuthenticator;
+import org.apache.dolphinscheduler.api.security.impl.oidc.OidcAuthenticator;
+import org.apache.dolphinscheduler.api.security.impl.oidc.OidcConfigProperties;
 import org.apache.dolphinscheduler.api.service.SessionService;
 import org.apache.dolphinscheduler.api.service.UsersService;
 import org.apache.dolphinscheduler.api.utils.Result;
@@ -42,11 +45,13 @@ import org.apache.dolphinscheduler.dao.entity.User;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.http.HttpStatus;
 
+import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Optional;
 import java.util.UUID;
 import java.util.stream.Collectors;
 
@@ -61,6 +66,7 @@ import lombok.extern.slf4j.Slf4j;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.web.bind.annotation.DeleteMapping;
 import org.springframework.web.bind.annotation.GetMapping;
+import org.springframework.web.bind.annotation.PathVariable;
 import org.springframework.web.bind.annotation.PostMapping;
 import org.springframework.web.bind.annotation.RequestAttribute;
 import org.springframework.web.bind.annotation.RequestMapping;
@@ -82,17 +88,27 @@ import io.swagger.v3.oas.annotations.tags.Tag;
 @Slf4j
 public class LoginController extends BaseController {
 
-    @Autowired
-    private SessionService sessionService;
+    private final SessionService sessionService;
+    private final Authenticator authenticator;
+    private final OAuth2Configuration oAuth2Configuration;
+    private final OidcConfigProperties oidcConfigProperties;
+    private final UsersService usersService;
+    private final ApiConfig apiConfig;
 
     @Autowired
-    private Authenticator authenticator;
-
-    @Autowired(required = false)
-    private OAuth2Configuration oAuth2Configuration;
-
-    @Autowired
-    private UsersService usersService;
+    public LoginController(SessionService sessionService,
+                           Authenticator authenticator,
+                           UsersService usersService,
+                           Optional<OAuth2Configuration> oAuth2Configuration,
+                           Optional<OidcConfigProperties> oidcConfigProperties,
+                           ApiConfig apiConfig) {
+        this.sessionService = sessionService;
+        this.authenticator = authenticator;
+        this.usersService = usersService;
+        this.oAuth2Configuration = oAuth2Configuration.orElse(null);
+        this.oidcConfigProperties = oidcConfigProperties.orElse(null);
+        this.apiConfig = apiConfig;
+    }
 
     /**
      * login
@@ -152,6 +168,10 @@ public class LoginController extends BaseController {
     @GetMapping(value = "/login/sso")
     @ApiException(NOT_SUPPORT_SSO)
     public Result ssoLogin(HttpServletRequest request) {
+        if (authenticator instanceof OidcAuthenticator) {
+            return Result.success(null);
+        }
+
         if (authenticator instanceof AbstractSsoAuthenticator) {
             String randomState = UUID.randomUUID().toString();
             HttpSession session = request.getSession();
@@ -207,6 +227,31 @@ public class LoginController extends BaseController {
         return Result.success(providers);
     }
 
+    /**
+     * Get OIDC providers
+     * @return list of OIDC providers
+     */
+    @Operation(summary = "getOidcProviders", description = "GET_OIDC_PROVIDERS")
+    @GetMapping("/oidc-providers")
+    public Result<List<Map<String, String>>> oidcProviders() {
+        if (oidcConfigProperties == null || !oidcConfigProperties.isEnable()
+                || oidcConfigProperties.getProviders() == null) {
+            return Result.success(new ArrayList<>());
+        }
+
+        List<Map<String, String>> providers = oidcConfigProperties.getProviders().entrySet().stream()
+                .map(entry -> {
+                    Map<String, String> provider = new HashMap<>();
+                    provider.put("id", entry.getKey());
+                    provider.put("displayName", entry.getValue().getDisplayName());
+                    provider.put("iconUri", entry.getValue().getIconUri());
+                    return provider;
+                })
+                .collect(Collectors.toList());
+
+        return Result.success(providers);
+    }
+
     @SneakyThrows
     @Operation(summary = "redirectToOauth2", description = "REDIRECT_TO_OAUTH2_LOGIN")
     @GetMapping("redirect/login/oauth2")
@@ -263,4 +308,97 @@ public class LoginController extends BaseController {
                     "oauth2", "oauth2 auth error"));
         }
     }
+
+    /**
+     * Handle OIDC callback
+     *
+     * @param code       authorization code
+     * @param state      state parameter
+     * @param response   HTTP response
+     */
+    @SneakyThrows
+    @Operation(summary = "handleOidcCallback", description = "HANDLE_OIDC_CALLBACK")
+    @GetMapping("/login/oauth2/code/{providerId}")
+    public void handleOidcCallback(@PathVariable String providerId,
+                                   @RequestParam(name = "code", required = false) String code,
+                                   @RequestParam(name = "error", required = false) String error,
+                                   @RequestParam(name = "state") String state,
+                                   HttpServletResponse response) throws IOException {
+
+        if (!state.startsWith(providerId + ":")) {
+            log.error("OIDC login failed: State parameter does not match the provider ID.");
+            response.sendRedirect("/dolphinscheduler/ui/#/login?error=oidc_invalid_state");
+            return;
+        }
+
+        // Handle login failure from OIDC provider
+        if (error != null) {
+            String sanitizedError = error.replaceAll("[\n\r\t]", "_");
+            log.error("OIDC login failed with error: {}.", sanitizedError);
+            response.sendRedirect("/dolphinscheduler/ui/#/login?error=oidc_login_failed");
+            return;
+        }
+
+        // Handle the case where code is missing without an error
+        if (code == null) {
+            log.error("OIDC login failed: The authorization code was not provided.");
+            response.sendRedirect("/dolphinscheduler/ui/#/login?error=oidc_missing_code");
+            return;
+        }
+
+        try {
+            if (!(authenticator instanceof OidcAuthenticator)) {
+                log.error("OIDC authentication is not active or authenticator type is incorrect.");
+                response.sendRedirect("/dolphinscheduler/ui/#/login?error=oidc_not_enabled");
+                return;
+            }
+
+            User user = ((OidcAuthenticator) authenticator).login(state, code);
+
+            if (user == null) {
+                log.error("OIDC authentication failed. User could not be authenticated or created.");
+                response.sendRedirect("/dolphinscheduler/ui/#/login?error=oidc_authentication_failed");
+                return;
+            }
+
+            Session session = sessionService.createSessionIfAbsent(user);
+
+            response.setStatus(HttpStatus.SC_MOVED_TEMPORARILY);
+            response.sendRedirect(String.format("%s/login?sessionId=%s&authType=%s",
+                    apiConfig.getUiUrl(), session.getId(), "oidc"));
+        } catch (Exception ex) {
+            log.error("A critical error occurred during the OIDC callback process.", ex);
+            try {
+                response.sendRedirect("/dolphinscheduler/ui/#/login?error=oidc_critical_error");
+            } catch (IOException e) {
+                log.error("Failed to redirect to login page after a critical error.", e);
+            }
+        }
+    }
+
+    @Operation(summary = "redirectToOidc", description = "REDIRECT_TO_OIDC_LOGIN")
+    @GetMapping("/oauth2/authorization/{providerId}")
+    public void redirectToOidc(@PathVariable String providerId, HttpServletRequest request,
+                               HttpServletResponse response) throws IOException {
+
+        // Validate the providerId before using it
+        if (oidcConfigProperties == null || oidcConfigProperties.getProviders() == null
+                || !oidcConfigProperties.getProviders().containsKey(providerId)) {
+            log.error("Invalid OIDC provider ID requested: {}", providerId);
+            response.sendRedirect("/dolphinscheduler/ui/#/login?error=invalid_provider");
+            return;
+        }
+
+        String state = providerId + ":" + UUID.randomUUID().toString();
+        request.getSession().setAttribute(Constants.SSO_LOGIN_USER_STATE, state);
+        String authorizationUrl = ((OidcAuthenticator) authenticator).getSignInUrl(state);
+
+        if (authorizationUrl == null) {
+            log.error("OIDC authorization URL is null for providerId: {}", providerId);
+            response.sendRedirect("/dolphinscheduler/ui/#/login?error=oidc_authorization_url_null");
+            return;
+        }
+
+        response.sendRedirect(authorizationUrl);
+    }
 }
