@@ -18,7 +18,6 @@
 package org.apache.dolphinscheduler.api.k8s;
 
 import org.apache.dolphinscheduler.dao.entity.K8sNamespace;
-import org.apache.dolphinscheduler.remote.exceptions.RemotingException;
 
 import java.util.Optional;
 
@@ -29,7 +28,6 @@ import org.yaml.snakeyaml.Yaml;
 import io.fabric8.kubernetes.api.model.Namespace;
 import io.fabric8.kubernetes.api.model.NamespaceList;
 import io.fabric8.kubernetes.api.model.ObjectMeta;
-import io.fabric8.kubernetes.api.model.ResourceQuota;
 import io.fabric8.kubernetes.client.KubernetesClient;
 
 /**
@@ -42,17 +40,15 @@ public class K8sClientService {
     @Autowired
     private K8sManager k8sManager;
 
-    public ResourceQuota upsertNamespaceAndResourceToK8s(K8sNamespace k8sNamespace,
-                                                         String yamlStr) throws RemotingException {
+    public void upsertNamespaceAndResourceToK8s(K8sNamespace k8sNamespace) {
         if (!checkNamespaceToK8s(k8sNamespace.getNamespace(), k8sNamespace.getClusterCode())) {
-            throw new RemotingException(String.format(
+            throw new RuntimeException(String.format(
                     "namespace %s does not exist in k8s cluster, please create namespace in k8s cluster first",
                     k8sNamespace.getNamespace()));
         }
-        return upsertNamespacedResourceToK8s(k8sNamespace, yamlStr);
     }
 
-    public Optional<Namespace> deleteNamespaceToK8s(String name, Long clusterCode) throws RemotingException {
+    public Optional<Namespace> deleteNamespaceToK8s(String name, Long clusterCode) {
         Optional<Namespace> result = getNamespaceFromK8s(name, clusterCode);
         if (result.isPresent()) {
             KubernetesClient client = k8sManager.getK8sClient(clusterCode);
@@ -66,34 +62,7 @@ public class K8sClientService {
         return getNamespaceFromK8s(name, clusterCode);
     }
 
-    private ResourceQuota upsertNamespacedResourceToK8s(K8sNamespace k8sNamespace,
-                                                        String yamlStr) throws RemotingException {
-
-        KubernetesClient client = k8sManager.getK8sClient(k8sNamespace.getClusterCode());
-
-        // 创建资源
-        ResourceQuota queryExist = client.resourceQuotas()
-                .inNamespace(k8sNamespace.getNamespace())
-                .withName(k8sNamespace.getNamespace())
-                .get();
-
-        ResourceQuota body = yaml.loadAs(yamlStr, ResourceQuota.class);
-
-        if (queryExist != null) {
-            if (k8sNamespace.getLimitsCpu() == null && k8sNamespace.getLimitsMemory() == null) {
-                client.resourceQuotas().inNamespace(k8sNamespace.getNamespace())
-                        .withName(k8sNamespace.getNamespace())
-                        .delete();
-                return null;
-            }
-        }
-
-        return client.resourceQuotas().inNamespace(k8sNamespace.getNamespace())
-                .withName(k8sNamespace.getNamespace())
-                .createOrReplace(body);
-    }
-
-    private Optional<Namespace> getNamespaceFromK8s(String name, Long clusterCode) throws RemotingException {
+    private Optional<Namespace> getNamespaceFromK8s(String name, Long clusterCode) {
         NamespaceList listNamespace =
                 k8sManager.getK8sClient(clusterCode).namespaces().list();
 
@@ -105,7 +74,7 @@ public class K8sClientService {
         return list;
     }
 
-    private boolean checkNamespaceToK8s(String name, Long clusterCode) throws RemotingException {
+    private boolean checkNamespaceToK8s(String name, Long clusterCode) {
         Optional<Namespace> result = getNamespaceFromK8s(name, clusterCode);
         return result.isPresent();
     }
