@@ -20,36 +20,13 @@ package org.apache.dolphinscheduler.api.service;
 import org.apache.dolphinscheduler.dao.entity.Session;
 import org.apache.dolphinscheduler.dao.entity.User;
 
-import javax.servlet.http.HttpServletRequest;
-
-/**
- * session service
- */
 public interface SessionService {
 
-    /**
-     * get user session from request
-     *
-     * @param request request
-     * @return session
-     */
-    Session getSession(HttpServletRequest request);
+    Session getSession(String sessionId);
 
-    /**
-     * create session
-     *
-     * @param user user
-     * @param ip ip
-     * @return session string
-     */
-    String createSession(User user, String ip);
+    Session createSessionIfAbsent(User user);
 
-    /**
-     * sign out
-     * remove ip restrictions
-     *
-     * @param ip   no use
-     * @param loginUser login user
-     */
-    void signOut(String ip, User loginUser);
+    void expireSession(Integer userId);
+
+    boolean isSessionExpire(Session session);
 }
