@@ -94,7 +94,30 @@ public class ProjectWorkerGroupRelationServiceImpl extends BaseServiceImpl
             return result;
         }
 
+        Project project = projectMapper.queryByCode(projectCode);
+        if (Objects.isNull(project)) {
+            putMsg(result, Status.PROJECT_NOT_EXIST);
+            return result;
+        }
+
+        /*
+         * Todo : For modification operations on projects, we should acquire project row locks. All project-related
+         * operations and modification/creation actions for workflows/task definitions within the project require
+         * acquiring row locks first
+         */
         if (CollectionUtils.isEmpty(workerGroups)) {
+            Set<String> projectWorkerGroupNames =
+                    projectWorkerGroupDao.queryAssignedWorkerGroupNamesByProjectCode(projectCode);
+            if (CollectionUtils.isNotEmpty(projectWorkerGroupNames)) {
+                Set<String> usedWorkerGroups = getAllUsedWorkerGroups(project);
+                if (CollectionUtils.isNotEmpty(usedWorkerGroups)) {
+                    Set<String> usedInProject = SetUtils.intersection(usedWorkerGroups, projectWorkerGroupNames);
+                    if (!usedInProject.isEmpty()) {
+                        throw new ServiceException(Status.USED_WORKER_GROUP_EXISTS, usedInProject);
+                    }
+                }
+            }
+
             boolean deleted = projectWorkerGroupDao.deleteByProjectCode(projectCode);
             if (deleted) {
                 putMsg(result, Status.SUCCESS);
@@ -104,12 +127,6 @@ public class ProjectWorkerGroupRelationServiceImpl extends BaseServiceImpl
             return result;
         }
 
-        Project project = projectMapper.queryByCode(projectCode);
-        if (Objects.isNull(project)) {
-            putMsg(result, Status.PROJECT_NOT_EXIST);
-            return result;
-        }
-
         Set<String> allWorkerGroupNames = new HashSet<>(workerGroupDao.queryAllWorkerGroupNames());
         workerGroupService.getConfigWorkerGroupPageDetail().forEach(
                 workerGroupPageDetail -> allWorkerGroupNames.add(workerGroupPageDetail.getName()));
@@ -125,26 +142,35 @@ public class ProjectWorkerGroupRelationServiceImpl extends BaseServiceImpl
         // check if assign worker group exists in the project
         Set<String> projectWorkerGroupNames =
                 projectWorkerGroupDao.queryAssignedWorkerGroupNamesByProjectCode(projectCode);
-        difference = SetUtils.difference(unauthorizedWorkerGroupNames, projectWorkerGroupNames);
+        Set<String> needDeletedWorkerGroups =
+                SetUtils.difference(projectWorkerGroupNames, unauthorizedWorkerGroupNames);
         Date now = new Date();
-        if (CollectionUtils.isNotEmpty(difference)) {
+
+        if (CollectionUtils.isNotEmpty(needDeletedWorkerGroups)) {
             Set<String> usedWorkerGroups = getAllUsedWorkerGroups(project);
-
-            if (CollectionUtils.isNotEmpty(usedWorkerGroups) && usedWorkerGroups.containsAll(difference)) {
-                throw new ServiceException(Status.USED_WORKER_GROUP_EXISTS,
-                        SetUtils.intersection(usedWorkerGroups, difference).toSet());
+            if (CollectionUtils.isNotEmpty(usedWorkerGroups) && CollectionUtils.isNotEmpty(needDeletedWorkerGroups)) {
+                Set<String> shouldNotDelete = SetUtils.intersection(usedWorkerGroups, needDeletedWorkerGroups);
+                if (CollectionUtils.isNotEmpty(shouldNotDelete)) {
+                    throw new ServiceException(Status.USED_WORKER_GROUP_EXISTS, shouldNotDelete);
+                }
             }
-
             boolean deleted =
-                    projectWorkerGroupDao.deleteByProjectCodeAndWorkerGroups(projectCode, new ArrayList<>(difference));
+                    projectWorkerGroupDao.deleteByProjectCodeAndWorkerGroups(projectCode,
+                            new ArrayList<>(needDeletedWorkerGroups));
             if (deleted) {
-                log.info("Success to delete worker groups [{}] for the project [{}] .", difference, project.getName());
+                log.info("Success to delete worker groups [{}] for the project [{}] .", needDeletedWorkerGroups,
+                        project.getName());
             } else {
-                log.error("Failed to delete worker groups [{}] for the project [{}].", difference, project.getName());
+                log.error("Failed to delete worker groups [{}] for the project [{}].", needDeletedWorkerGroups,
+                        project.getName());
                 throw new ServiceException(Status.ASSIGN_WORKER_GROUP_TO_PROJECT_ERROR);
             }
+        }
 
-            difference.forEach(workerGroupName -> {
+        Set<String> needAssignedWorkerGroups =
+                SetUtils.difference(unauthorizedWorkerGroupNames, projectWorkerGroupNames);
+        if (CollectionUtils.isNotEmpty(needAssignedWorkerGroups)) {
+            needAssignedWorkerGroups.forEach(workerGroupName -> {
                 ProjectWorkerGroup projectWorkerGroup = new ProjectWorkerGroup();
                 projectWorkerGroup.setProjectCode(projectCode);
                 projectWorkerGroup.setWorkerGroup(workerGroupName);
