@@ -43,9 +43,6 @@ import org.springframework.stereotype.Service;
 import com.baomidou.mybatisplus.core.metadata.IPage;
 import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
 
-/**
- * task group queue service
- */
 @Service
 @Slf4j
 public class TaskGroupQueueServiceImpl extends BaseServiceImpl implements TaskGroupQueueService {
@@ -68,7 +65,7 @@ public class TaskGroupQueueServiceImpl extends BaseServiceImpl implements TaskGr
     @Override
     public Map<String, Object> queryTasksByGroupId(User loginUser,
                                                    String taskName,
-                                                   String processName,
+                                                   String workflowInstanceName,
                                                    Integer status,
                                                    int groupId,
                                                    int pageNo,
@@ -87,7 +84,7 @@ public class TaskGroupQueueServiceImpl extends BaseServiceImpl implements TaskGr
         IPage<TaskGroupQueue> taskGroupQueue = taskGroupQueueMapper.queryTaskGroupQueueByTaskGroupIdPaging(
                 page,
                 taskName,
-                processName,
+                workflowInstanceName,
                 status,
                 groupId,
                 projects);
@@ -100,80 +97,11 @@ public class TaskGroupQueueServiceImpl extends BaseServiceImpl implements TaskGr
         return result;
     }
 
-    /**
-     * query tasks in task group queue by project id
-     *
-     * @param loginUser login user
-     * @param pageNo    page no
-     * @param pageSize  page size
-     * @param processId process id
-     * @return tasks list
-     */
-    @Override
-    public Map<String, Object> queryTasksByProcessId(User loginUser, int pageNo, int pageSize, int processId) {
-        return this.doQuery(loginUser, pageNo, pageSize, processId);
-    }
-
-    /**
-     * query all tasks in task group queue
-     *
-     * @param loginUser login user
-     * @param pageNo    page no
-     * @param pageSize  page size
-     * @return tasks list
-     */
-    @Override
-    public Map<String, Object> queryAllTasks(User loginUser, int pageNo, int pageSize) {
-        return this.doQuery(loginUser, pageNo, pageSize, 0);
-    }
-
-    public Map<String, Object> doQuery(User loginUser, int pageNo, int pageSize,
-                                       int groupId) {
-        Map<String, Object> result = new HashMap<>();
-
-        Page<TaskGroupQueue> page = new Page<>(pageNo, pageSize);
-        IPage<TaskGroupQueue> taskGroupQueue = taskGroupQueueMapper.queryTaskGroupQueuePaging(page, groupId);
-
-        PageInfo<TaskGroupQueue> pageInfo = new PageInfo<>(pageNo, pageSize);
-        pageInfo.setTotal((int) taskGroupQueue.getTotal());
-        pageInfo.setTotalList(taskGroupQueue.getRecords());
-
-        result.put(Constants.DATA_LIST, pageInfo);
-        putMsg(result, Status.SUCCESS);
-
-        return result;
-    }
-
-    /**
-     * delete by task id
-     *
-     * @param taskId task id
-     * @return TaskGroupQueue entity
-     */
-
-    @Override
-    public boolean deleteByTaskId(int taskId) {
-        return taskGroupQueueMapper.deleteByTaskId(taskId) == 1;
-    }
-
-    @Override
-    public void deleteByTaskInstanceIds(List<Integer> taskInstanceIds) {
-        if (CollectionUtils.isEmpty(taskInstanceIds)) {
-            return;
-        }
-        taskGroupQueueMapper.deleteByTaskInstanceIds(taskInstanceIds);
-    }
-
     @Override
     public void deleteByWorkflowInstanceId(Integer workflowInstanceId) {
         taskGroupQueueMapper.deleteByWorkflowInstanceId(workflowInstanceId);
     }
 
-    @Override
-    public void forceStartTask(int queueId, int forceStart) {
-        taskGroupQueueMapper.updateForceStart(queueId, forceStart);
-    }
-
     @Override
     public void modifyPriority(Integer queueId, Integer priority) {
         taskGroupQueueMapper.modifyPriority(queueId, priority);
