@@ -38,6 +38,7 @@ import org.apache.dolphinscheduler.dao.repository.WorkflowTaskLineageDao;
 
 import java.text.MessageFormat;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.List;
 import java.util.Optional;
 import java.util.stream.Collectors;
@@ -189,10 +190,26 @@ public class WorkflowLineageServiceImpl extends BaseServiceImpl implements Workf
             if (workflowTaskLineage.getTaskDefinitionCode() != 0) {
                 TaskDefinition taskDefinition =
                         taskDefinitionMapper.queryByCode(workflowTaskLineage.getTaskDefinitionCode());
+                // Handle dirty data scenario caused by historical bugs:
+                // There may be orphaned lineage records referencing deleted task definitions.
+                // Skip these records to prevent NPE and ensure the method continues processing.
+                // Note: These orphaned records should be cleaned up by a background cleanup task,
+                // not here to avoid side effects in a read-only query method.
+                if (taskDefinition == null) {
+                    log.warn(
+                            "Orphaned lineage record detected: taskDefinitionCode {} not found, workflowTaskLineageId: {}. "
+                                    + "This dirty data should be cleaned up by a background task.",
+                            workflowTaskLineage.getTaskDefinitionCode(), workflowTaskLineage.getId());
+                    continue;
+                }
                 taskName = taskDefinition.getName();
             }
             taskDepStrList.add(String.format(Constants.FORMAT_S_S_COLON, workflowDefinition.getName(), taskName));
         }
+        // If no valid task dependencies found, return empty Optional to indicate no dependencies.
+        if (taskDepStrList.isEmpty()) {
+            return Optional.empty();
+        }
 
         String taskDepStr = String.join(Constants.COMMA, taskDepStrList);
         if (taskCode != 0) {
@@ -225,29 +242,38 @@ public class WorkflowLineageServiceImpl extends BaseServiceImpl implements Workf
 
         List<WorkflowDefinition> workflowDefinitionList =
                 workflowDefinitionMapper.queryByCodes(workflowTaskLineageList.stream()
-                        .map(WorkflowTaskLineage::getDeptWorkflowDefinitionCode).distinct()
+                        .map(WorkflowTaskLineage::getWorkflowDefinitionCode).distinct()
                         .collect(Collectors.toList()));
         List<TaskDefinition> taskDefinitionList = taskDefinitionMapper.queryByCodeList(workflowTaskLineageList.stream()
-                .map(WorkflowTaskLineage::getDeptTaskDefinitionCode).distinct().collect(Collectors.toList()));
-        for (TaskDefinition taskDefinition : taskDefinitionList) {
+                .map(WorkflowTaskLineage::getTaskDefinitionCode).filter(code -> code != 0).distinct()
+                .collect(Collectors.toList()));
+
+        for (WorkflowTaskLineage workflowLineage : workflowTaskLineageList) {
             DependentWorkflowDefinition dependentWorkflowDefinition = new DependentWorkflowDefinition();
-            workflowTaskLineageList.stream()
-                    .filter(workflowLineage -> workflowLineage.getDeptTaskDefinitionCode() == taskDefinition.getCode())
-                    .findFirst()
-                    .ifPresent(workflowLineage -> {
-                        dependentWorkflowDefinition
-                                .setWorkflowDefinitionCode(workflowLineage.getDeptWorkflowDefinitionCode());
-                        dependentWorkflowDefinition.setTaskDefinitionCode(taskDefinition.getCode());
-                        dependentWorkflowDefinition.setTaskParams(taskDefinition.getTaskParams());
-                        dependentWorkflowDefinition.setWorkerGroup(taskDefinition.getWorkerGroup());
-                    });
+            dependentWorkflowDefinition.setWorkflowDefinitionCode(workflowLineage.getWorkflowDefinitionCode());
+            dependentWorkflowDefinition.setTaskDefinitionCode(workflowLineage.getTaskDefinitionCode());
+
+            // If taskDefinitionCode is 0, it means dependency on entire workflow, taskParams and workerGroup remain
+            // null
+            if (workflowLineage.getTaskDefinitionCode() != 0) {
+                taskDefinitionList.stream()
+                        .filter(taskDefinition -> taskDefinition.getCode() == workflowLineage.getTaskDefinitionCode())
+                        .findFirst()
+                        .ifPresent(taskDefinition -> {
+                            dependentWorkflowDefinition.setTaskParams(taskDefinition.getTaskParams());
+                            dependentWorkflowDefinition.setWorkerGroup(taskDefinition.getWorkerGroup());
+                        });
+            }
+
             workflowDefinitionList.stream()
-                    .filter(workflowDefinition -> workflowDefinition.getCode() == dependentWorkflowDefinition
+                    .filter(workflowDefinition -> workflowDefinition.getCode() == workflowLineage
                             .getWorkflowDefinitionCode())
                     .findFirst()
                     .ifPresent(workflowDefinition -> {
                         dependentWorkflowDefinition.setWorkflowDefinitionVersion(workflowDefinition.getVersion());
                     });
+
+            dependentWorkflowDefinitionList.add(dependentWorkflowDefinition);
         }
 
         return dependentWorkflowDefinitionList;
@@ -302,8 +328,26 @@ public class WorkflowLineageServiceImpl extends BaseServiceImpl implements Workf
     }
 
     @Override
-    public int updateWorkflowLineage(List<WorkflowTaskLineage> workflowTaskLineages) {
-        return workflowTaskLineageDao.updateWorkflowTaskLineage(workflowTaskLineages);
+    public int updateWorkflowLineage(long workflowDefinitionCode, List<WorkflowTaskLineage> workflowTaskLineages) {
+        // Remove existing lineage first to keep data consistent
+        workflowTaskLineageDao.batchDeleteByWorkflowDefinitionCode(
+                Collections.singletonList(workflowDefinitionCode));
+
+        if (CollectionUtils.isEmpty(workflowTaskLineages)) {
+            log.info("Current lineage is empty, workflowDefinitionCode: {}",
+                    workflowDefinitionCode);
+            return 0;
+        }
+
+        int insertResult = workflowTaskLineageDao.batchInsert(workflowTaskLineages);
+        if (insertResult <= 0) {
+            log.error("Save workflow lineage error, workflowDefinitionCode: {}", workflowDefinitionCode);
+            throw new ServiceException(Status.CREATE_WORKFLOW_LINEAGE_ERROR);
+        }
+
+        log.info("Save workflow lineage complete, workflowDefinitionCode: {}, inserted rows: {}",
+                workflowDefinitionCode, insertResult);
+        return insertResult;
     }
 
     @Override
