@@ -14,35 +14,36 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+
 package org.apache.dolphinscheduler.api.exceptions;
 
 import org.apache.dolphinscheduler.api.enums.Status;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 
 public class ServiceExceptionTest {
 
     @Test
     public void getCodeTest() {
         ServiceException serviceException = new ServiceException();
-        Assert.assertEquals(Status.INTERNAL_SERVER_ERROR_ARGS.getCode(), serviceException.getCode());
+        Assertions.assertEquals(Status.INTERNAL_SERVER_ERROR_ARGS.getCode(), serviceException.getCode());
 
         serviceException = new ServiceException(Status.ALERT_GROUP_EXIST);
-        Assert.assertEquals(Status.ALERT_GROUP_EXIST.getCode(), serviceException.getCode());
+        Assertions.assertEquals(Status.ALERT_GROUP_EXIST.getCode(), serviceException.getCode());
 
         serviceException = new ServiceException(10012, "alarm group already exists");
-        Assert.assertEquals(10012, serviceException.getCode());
+        Assertions.assertEquals(10012, serviceException.getCode());
     }
     @Test
     public void getMessageTest() {
         ServiceException serviceException = new ServiceException();
-        Assert.assertEquals(Status.INTERNAL_SERVER_ERROR_ARGS.getMsg(), serviceException.getMessage());
+        Assertions.assertEquals(Status.INTERNAL_SERVER_ERROR_ARGS.getMsg(), serviceException.getMessage());
 
         serviceException = new ServiceException(Status.ALERT_GROUP_EXIST);
-        Assert.assertNotNull(serviceException.getMessage());
+        Assertions.assertNotNull(serviceException.getMessage());
 
         serviceException = new ServiceException(10012, "alarm group already exists");
-        Assert.assertNotNull(serviceException.getMessage());
+        Assertions.assertNotNull(serviceException.getMessage());
     }
 }
