@@ -26,20 +26,20 @@ import org.apache.dolphinscheduler.dao.mapper.EnvironmentWorkerGroupRelationMapp
 import java.util.Map;
 
 import org.assertj.core.util.Lists;
-import org.junit.Assert;
-import org.junit.Test;
-import org.junit.runner.RunWith;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.ExtendWith;
 import org.mockito.InjectMocks;
 import org.mockito.Mock;
 import org.mockito.Mockito;
-import org.mockito.junit.MockitoJUnitRunner;
+import org.mockito.junit.jupiter.MockitoExtension;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 /**
  * environment service test
  */
-@RunWith(MockitoJUnitRunner.class)
+@ExtendWith(MockitoExtension.class)
 public class EnvironmentWorkerGroupRelationServiceTest {
 
     public static final Logger logger = LoggerFactory.getLogger(EnvironmentWorkerGroupRelationServiceTest.class);
@@ -52,18 +52,20 @@ public class EnvironmentWorkerGroupRelationServiceTest {
 
     @Test
     public void testQueryEnvironmentWorkerGroupRelation() {
-        Mockito.when(relationMapper.queryByEnvironmentCode(1L)).thenReturn(Lists.newArrayList(new EnvironmentWorkerGroupRelation()));
+        Mockito.when(relationMapper.queryByEnvironmentCode(1L))
+                .thenReturn(Lists.newArrayList(new EnvironmentWorkerGroupRelation()));
         Map<String, Object> result = relationService.queryEnvironmentWorkerGroupRelation(1L);
         logger.info(result.toString());
-        Assert.assertEquals(Status.SUCCESS,result.get(Constants.STATUS));
+        Assertions.assertEquals(Status.SUCCESS, result.get(Constants.STATUS));
     }
 
     @Test
     public void testQueryAllEnvironmentWorkerGroupRelationList() {
-        Mockito.when(relationMapper.selectList(Mockito.any())).thenReturn(Lists.newArrayList(new EnvironmentWorkerGroupRelation()));
+        Mockito.when(relationMapper.selectList(Mockito.any()))
+                .thenReturn(Lists.newArrayList(new EnvironmentWorkerGroupRelation()));
         Map<String, Object> result = relationService.queryAllEnvironmentWorkerGroupRelationList();
         logger.info(result.toString());
-        Assert.assertEquals(Status.SUCCESS,result.get(Constants.STATUS));
+        Assertions.assertEquals(Status.SUCCESS, result.get(Constants.STATUS));
     }
 
 }
