@@ -17,76 +17,34 @@
 
 package org.apache.dolphinscheduler.common.constants;
 
-import org.apache.commons.lang3.SystemUtils;
-
 import java.time.Duration;
 import java.util.regex.Pattern;
 
+import lombok.experimental.UtilityClass;
+
+@UtilityClass
 public final class Constants {
 
-    private Constants() {
-        throw new UnsupportedOperationException("Construct Constants");
-    }
-
-    public static final String AUTO_CLOSE_ALERT = "alert.auto-close";
-
     /**
      * common properties path
      */
     public static final String COMMON_PROPERTIES_PATH = "/common.properties";
 
     public static final String REMOTE_LOGGING_YAML_PATH = "/remote-logging.yaml";
+    public static final String AWS_YAML_PATH = "/aws.yaml";
+    public static final String RESOURCE_CENTER_YAML_PATH = "/resource-center.yaml";
 
-    public static final String FORMAT_SS = "%s%s";
     public static final String FORMAT_S_S = "%s/%s";
     public static final String FORMAT_S_S_COLON = "%s:%s";
     public static final String FOLDER_SEPARATOR = "/";
 
-    public static final String RESOURCE_TYPE_FILE = "resources";
-
-    public static final String RESOURCE_TYPE_UDF = "udfs";
-
     public static final String EMPTY_STRING = "";
-    public static final int MAX_FILE_SIZE = 1024 * 1024 * 1024;
 
     /**
      * resource.hdfs.fs.defaultFS
      */
     public static final String FS_DEFAULT_FS = "resource.hdfs.fs.defaultFS";
 
-    /**
-     * hdfs defaultFS property name. Should be consistent with the property name in hdfs-site.xml
-     */
-    public static final String HDFS_DEFAULT_FS = "fs.defaultFS";
-
-    /**
-     * hadoop configuration
-     */
-    public static final String HADOOP_RM_STATE_ACTIVE = "ACTIVE";
-
-    public static final String HADOOP_RESOURCE_MANAGER_HTTPADDRESS_PORT = "resource.manager.httpaddress.port";
-
-    /**
-     * yarn.resourcemanager.ha.rm.ids
-     */
-    public static final String YARN_RESOURCEMANAGER_HA_RM_IDS = "yarn.resourcemanager.ha.rm.ids";
-
-    /**
-     * yarn.application.status.address
-     */
-    public static final String YARN_APPLICATION_STATUS_ADDRESS = "yarn.application.status.address";
-
-    /**
-     * yarn.job.history.status.address
-     */
-    public static final String YARN_JOB_HISTORY_STATUS_ADDRESS = "yarn.job.history.status.address";
-
-    /**
-     * hdfs configuration
-     * resource.hdfs.root.user
-     */
-    public static final String HDFS_ROOT_USER = "resource.hdfs.root.user";
-
     /**
      * hdfs/s3 configuration
      * resource.storage.upload.base.path
@@ -98,16 +56,6 @@ public final class Constants {
      */
     public static final String DATA_BASEDIR_PATH = "data.basedir.path";
 
-    /**
-     * dolphinscheduler.env.path
-     */
-    public static final String DOLPHINSCHEDULER_ENV_PATH = "dolphinscheduler.env.path";
-
-    /**
-     * environment properties default path
-     */
-    public static final String ENV_PATH = "dolphinscheduler_env.sh";
-
     /**
      * resource.view.suffixs
      */
@@ -121,6 +69,11 @@ public final class Constants {
      */
     public static final String DEVELOPMENT_STATE = "development.state";
 
+    /**
+     * shell.kill.wait.timeout: this property defines the wait timeout in seconds before using SIGKILL.
+     */
+    public static final String SHELL_KILL_WAIT_TIMEOUT = "shell.kill.wait.timeout";
+
     /**
      * sudo enable
      */
@@ -131,30 +84,7 @@ public final class Constants {
      */
     public static final String RESOURCE_STORAGE_TYPE = "resource.storage.type";
 
-    public static final String AWS_S3_BUCKET_NAME = "resource.aws.s3.bucket.name";
-    public static final String AWS_END_POINT = "resource.aws.s3.endpoint";
-
-    public static final String ALIBABA_CLOUD_OSS_BUCKET_NAME = "resource.alibaba.cloud.oss.bucket.name";
-    public static final String ALIBABA_CLOUD_OSS_END_POINT = "resource.alibaba.cloud.oss.endpoint";
-
-    public static final String GOOGLE_CLOUD_STORAGE_BUCKET_NAME = "resource.google.cloud.storage.bucket.name";
-
-    public static final String GOOGLE_CLOUD_STORAGE_CREDENTIAL = "resource.google.cloud.storage.credential";
-
-    public static final String AZURE_BLOB_STORAGE_CONNECTION_STRING = "resource.azure.blob.storage.connection.string";
-
-    public static final String AZURE_BLOB_STORAGE_CONTAINER_NAME = "resource.azure.blob.storage.container.name";
-
-    public static final String AZURE_BLOB_STORAGE_ACCOUNT_NAME = "resource.azure.blob.storage.account.name";
-
-    public static final String HUAWEI_CLOUD_OBS_BUCKET_NAME = "resource.huawei.cloud.obs.bucket.name";
-    public static final String HUAWEI_CLOUD_OBS_END_POINT = "resource.huawei.cloud.obs.endpoint";
-
-    /**
-     * fetch applicationId way
-     */
-    public static final String APPID_COLLECT = "appId.collect";
-    public static final String DEFAULT_COLLECT_WAY = "log";
+    public static final String AWS_S3_BUCKET_NAME = "aws.s3.bucket.name";
 
     /**
      * comma ,
@@ -166,16 +96,6 @@ public final class Constants {
      */
     public static final String COLON = ":";
 
-    /**
-     * period .
-     */
-    public static final String PERIOD = ".";
-
-    /**
-     * QUESTION ?
-     */
-    public static final String QUESTION = "?";
-
     /**
      * SPACE " "
      */
@@ -280,11 +200,6 @@ public final class Constants {
      */
     public static final int ALL_PERMISSIONS = READ_PERMISSION | WRITE_PERMISSION | EXECUTE_PERMISSION;
 
-    /**
-     * max task timeout
-     */
-    public static final int MAX_TASK_TIMEOUT = 24 * 3600;
-
     /**
      * forbid running task
      */
@@ -295,8 +210,6 @@ public final class Constants {
      */
     public static final String FLOWNODE_RUN_FLAG_NORMAL = "NORMAL";
 
-    public static final String COMMON_TASK_TYPE = "common";
-
     public static final String DEFAULT = "default";
     public static final String PASSWORD = "password";
     public static final String XXXXXX = "******";
@@ -318,11 +231,6 @@ public final class Constants {
      */
     public static final long SLEEP_TIME_MILLIS = 1_000L;
 
-    /**
-     * short sleep 100ms
-     */
-    public static final long SLEEP_TIME_MILLIS_SHORT = 100L;
-
     public static final Duration SERVER_CLOSE_WAIT_TIME = Duration.ofSeconds(3);
 
     /**
@@ -351,14 +259,14 @@ public final class Constants {
     public static final int EXIT_CODE_FAILURE = -1;
 
     /**
-     * process or task definition failure
+     * workflow or task definition failure
      */
     public static final int DEFINITION_FAILURE = -1;
 
     public static final int OPPOSITE_VALUE = -1;
 
     /**
-     * process or task definition first version
+     * workflow or task definition first version
      */
     public static final int VERSION_FIRST = 1;
 
@@ -375,27 +283,19 @@ public final class Constants {
      */
     public static final String UNDERLINE = "_";
 
-    public static final String PID = SystemUtils.IS_OS_WINDOWS ? "handle" : "pid";
-
     public static final String STAR = "*";
-    public static final char N = 'N';
     public static final String GLOBAL_PARAMS = "globalParams";
     public static final String LOCAL_PARAMS = "localParams";
-    public static final String SUBPROCESS_INSTANCE_ID = "subProcessInstanceId";
-    public static final String PROCESS_INSTANCE_STATE = "processInstanceState";
+    public static final String SUBWORKFLOW_INSTANCE_ID = "subWorkflowInstanceId";
+    public static final String WORKFLOW_INSTANCE_STATE = "workflowInstanceState";
     public static final String PARENT_WORKFLOW_INSTANCE = "parentWorkflowInstance";
-    public static final String CONDITION_RESULT = "conditionResult";
-    public static final String SWITCH_RESULT = "switchResult";
-    public static final String WAIT_START_TIMEOUT = "waitStartTimeout";
-    public static final String DEPENDENCE = "dependence";
     public static final String TASK_LIST = "taskList";
     public static final String QUEUE = "queue";
     public static final String QUEUE_NAME = "queueName";
-    public static final int LOG_QUERY_SKIP_LINE_NUMBER = 0;
-    public static final int LOG_QUERY_LIMIT = 4096;
-    public static final String ALIAS = "alias";
-    public static final String CONTENT = "content";
-    public static final String DEPENDENT_SPLIT = ":||";
+
+    /**
+     * dependent task
+     */
     public static final long DEPENDENT_ALL_TASK_CODE = -1;
     public static final long DEPENDENT_WORKFLOW_CODE = 0;
 
@@ -409,11 +309,6 @@ public final class Constants {
      */
     public static final String KERBEROS = "kerberos";
 
-    /**
-     * kerberos expire time
-     */
-    public static final String KERBEROS_EXPIRE_TIME = "kerberos.expire.time";
-
     /**
      * java.security.krb5.conf
      */
@@ -450,29 +345,8 @@ public final class Constants {
      */
     public static final String SSO_LOGIN_USER_STATE = "sso.login.user.state";
 
-    public static final String WORKFLOW_INSTANCE_ID_MDC_KEY = "workflowInstanceId";
     public static final String TASK_INSTANCE_ID_MDC_KEY = "taskInstanceId";
 
-    /**
-     * double brackets left
-     */
-    public static final String DOUBLE_BRACKETS_LEFT = "{{";
-
-    /**
-     * double brackets left
-     */
-    public static final String DOUBLE_BRACKETS_RIGHT = "}}";
-
-    /**
-     * double brackets left
-     */
-    public static final String DOUBLE_BRACKETS_LEFT_SPACE = "{ {";
-
-    /**
-     * double brackets left
-     */
-    public static final String DOUBLE_BRACKETS_RIGHT_SPACE = "} }";
-
     /**
      * status
      */
@@ -483,11 +357,6 @@ public final class Constants {
      */
     public static final String MSG = "msg";
 
-    /**
-     * data total
-     */
-    public static final String COUNT = "count";
-
     /**
      * page size
      */
@@ -511,11 +380,9 @@ public final class Constants {
 
     public static final String TOTAL = "total";
 
-    /**
-     * workflow
-     */
-    public static final String WORKFLOW_LIST = "workFlowList";
-    public static final String WORKFLOW_RELATION_LIST = "workFlowRelationList";
+    public static final long DEFAULT_PROJECT_CODE = 0;
+
+    public static final long DEPENDENT_ALL_TASK = 0;
 
     /**
      * session user
@@ -533,7 +400,7 @@ public final class Constants {
      * session timeout
      */
     public static final int SESSION_TIME_OUT = 7200;
-    public static final String UDF = "UDF";
+
     public static final String CLASS = "class";
 
     /**
@@ -555,22 +422,6 @@ public final class Constants {
      */
     public static final String SH = "sh";
 
-    /**
-     * pstree, get pud and sub pid
-     */
-    public static final String PSTREE = "pstree";
-
-    /**
-     * dry run flag
-     */
-    public static final int DRY_RUN_FLAG_NO = 0;
-    public static final int DRY_RUN_FLAG_YES = 1;
-
-    /**
-     * data.quality.error.output.path
-     */
-    public static final String DATA_QUALITY_ERROR_OUTPUT_PATH = "data-quality.error.output.path";
-
     /**
      * use for k8s
      */
@@ -582,18 +433,12 @@ public final class Constants {
      * schedule timezone
      */
     public static final String SCHEDULE_TIMEZONE = "schedule_timezone";
-    public static final int RESOURCE_FULL_NAME_MAX_LENGTH = 128;
 
     /**
      * tenant
      */
     public static final int TENANT_FULL_NAME_MAX_LENGTH = 30;
 
-    /**
-     * schedule time  the amount of date data is too large, affecting the memory, so set 100
-     */
-    public static final int SCHEDULE_TIME_MAX_LENGTH = 100;
-
     /**
      * password max and min LENGTH
      */
@@ -614,12 +459,6 @@ public final class Constants {
 
     public static final String SECURITY_CONFIG_TYPE_LDAP = "LDAP";
 
-    /**
-     * test flag
-     */
-    public static final int TEST_FLAG_NO = 0;
-    public static final int TEST_FLAG_YES = 1;
-
     /**
      * Task Types
      */
@@ -627,7 +466,6 @@ public final class Constants {
     public static final String TYPE_DATA_INTEGRATION = "DataIntegration";
     public static final String TYPE_CLOUD = "Cloud";
     public static final String TYPE_LOGIC = "Logic";
-    public static final String TYPE_DATA_QUALITY = "DataQuality";
     public static final String TYPE_OTHER = "Other";
     public static final String TYPE_MACHINE_LEARNING = "MachineLearning";
 
@@ -662,15 +500,6 @@ public final class Constants {
     /** string no */
     public static final String STRING_NO = "NO";
 
-    public static final String SMALL = "small";
-
-    public static final String CHANGE = "change";
-
-    /**
-     *  support hive datasource in one session
-     */
-    public static final String SUPPORT_HIVE_ONE_SESSION = "support.hive.oneSession";
-
     public static final Integer QUERY_ALL_ON_SYSTEM = 0;
     public static final Integer QUERY_ALL_ON_PROJECT = 1;
     public static final Integer QUERY_ALL_ON_WORKFLOW = 2;
@@ -695,19 +524,6 @@ public final class Constants {
 
     public static final String REMOTE_LOGGING_OSS_ENDPOINT = "remote.logging.oss.endpoint";
 
-    /**
-     * remote logging for S3
-     */
-    public static final String REMOTE_LOGGING_S3_ACCESS_KEY_ID = "remote.logging.s3.access.key.id";
-
-    public static final String REMOTE_LOGGING_S3_ACCESS_KEY_SECRET = "remote.logging.s3.access.key.secret";
-
-    public static final String REMOTE_LOGGING_S3_BUCKET_NAME = "remote.logging.s3.bucket.name";
-
-    public static final String REMOTE_LOGGING_S3_ENDPOINT = "remote.logging.s3.endpoint";
-
-    public static final String REMOTE_LOGGING_S3_REGION = "remote.logging.s3.region";
-
     /**
      * remote logging for GCS
      */
@@ -723,8 +539,16 @@ public final class Constants {
     public static final String REMOTE_LOGGING_ABS_CONTAINER_NAME = "remote.logging.abs.container.name";
 
     /**
-     * data quality
+     * remote logging for COS
      */
+    public static final String REMOTE_LOGGING_COS_ACCESS_KEY_ID = "remote.logging.cos.access.key.id";
+
+    public static final String REMOTE_LOGGING_COS_ACCESS_KEY_SECRET = "remote.logging.cos.access.key.secret";
+
+    public static final String REMOTE_LOGGING_COS_BUCKET_NAME = "remote.logging.cos.bucket.name";
+
+    public static final String REMOTE_LOGGING_COS_REGION = "remote.logging.cos.region";
+
     public static final String DATABASES_QUERY = "show databases";
     public static final String DATABASES_QUERY_PG = "SELECT datname FROM pg_database";
 
