@@ -17,6 +17,8 @@
 
 package org.apache.dolphinscheduler.common.enums;
 
+import lombok.Getter;
+
 import com.baomidou.mybatisplus.annotation.EnumValue;
 
 /**
@@ -27,7 +29,9 @@ import com.baomidou.mybatisplus.annotation.EnumValue;
  * have_map_variables
  * have_alert
  */
+@Getter
 public enum Flag {
+
     /**
      * 0 no
      * 1 yes
@@ -44,11 +48,10 @@ public enum Flag {
     private final int code;
     private final String descp;
 
-    public int getCode() {
-        return code;
-    }
-
-    public String getDescp() {
-        return descp;
+    public static Flag of(int code) {
+        if (code == 0) {
+            return NO;
+        }
+        return YES;
     }
 }
