@@ -17,8 +17,10 @@
 
 package org.apache.dolphinscheduler.common.utils;
 
+import static org.apache.dolphinscheduler.common.constants.Constants.AWS_YAML_PATH;
 import static org.apache.dolphinscheduler.common.constants.Constants.COMMON_PROPERTIES_PATH;
 import static org.apache.dolphinscheduler.common.constants.Constants.REMOTE_LOGGING_YAML_PATH;
+import static org.apache.dolphinscheduler.common.constants.Constants.RESOURCE_CENTER_YAML_PATH;
 
 import org.apache.dolphinscheduler.common.config.ImmutablePriorityPropertyDelegate;
 import org.apache.dolphinscheduler.common.config.ImmutablePropertyDelegate;
@@ -42,7 +44,7 @@ public class PropertyUtils {
     private final ImmutablePriorityPropertyDelegate propertyDelegate =
             new ImmutablePriorityPropertyDelegate(
                     new ImmutablePropertyDelegate(COMMON_PROPERTIES_PATH),
-                    new ImmutableYamlDelegate(REMOTE_LOGGING_YAML_PATH));
+                    new ImmutableYamlDelegate(REMOTE_LOGGING_YAML_PATH, AWS_YAML_PATH, RESOURCE_CENTER_YAML_PATH));
 
     public static String getString(String key) {
         return propertyDelegate.get(key.trim());
@@ -106,6 +108,19 @@ public class PropertyUtils {
         return matchedProperties;
     }
 
+    /**
+     * Get all properties with specified prefix, like: fs., will replace the prefix with newPrefix
+     */
+    public static Map<String, String> getByPrefix(String prefix, String newPrefix) {
+        Map<String, String> matchedProperties = new HashMap<>();
+        for (String propName : propertyDelegate.getPropertyKeys()) {
+            if (propName.startsWith(prefix)) {
+                matchedProperties.put(propName.replace(prefix, newPrefix), propertyDelegate.get(propName));
+            }
+        }
+        return matchedProperties;
+    }
+
     public static <T> Set<T> getSet(String key, Function<String, Set<T>> transformFunction, Set<T> defaultValue) {
         return propertyDelegate.get(key, transformFunction, defaultValue);
     }
