@@ -17,18 +17,19 @@
 
 package org.apache.dolphinscheduler.dao.entity;
 
+import org.apache.dolphinscheduler.plugin.task.api.enums.TaskExecutionStatus;
+
+import java.io.Serializable;
+import java.util.Date;
+
 import lombok.AllArgsConstructor;
 import lombok.Builder;
 import lombok.Data;
 import lombok.NoArgsConstructor;
 
-import java.io.Serializable;
-import java.util.Date;
-
 import com.fasterxml.jackson.annotation.JsonInclude;
 import com.fasterxml.jackson.annotation.JsonInclude.Include;
 import com.fasterxml.jackson.annotation.JsonProperty;
-import org.apache.dolphinscheduler.plugin.task.api.enums.TaskExecutionStatus;
 
 @Data
 @Builder
@@ -59,6 +60,8 @@ public class TaskAlertContent implements Serializable {
     private Date endTime;
     @JsonProperty("host")
     private String host;
+    @JsonProperty("taskPriority")
+    private String taskPriority;
     @JsonProperty("logPath")
     private String logPath;
 
