@@ -19,10 +19,8 @@ package org.apache.dolphinscheduler.dao.mapper;
 
 import org.apache.dolphinscheduler.dao.entity.AlertGroup;
 
-import org.apache.dolphinscheduler.dao.entity.User;
 import org.apache.ibatis.annotations.Param;
 
-import java.util.ArrayList;
 import java.util.List;
 
 import com.baomidou.mybatisplus.core.mapper.BaseMapper;
@@ -34,7 +32,6 @@ import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
  */
 public interface AlertGroupMapper extends BaseMapper<AlertGroup> {
 
-
     /**
      * alertgroup page
      * @param page page
@@ -44,7 +41,6 @@ public interface AlertGroupMapper extends BaseMapper<AlertGroup> {
     IPage<AlertGroup> queryAlertGroupPage(Page page,
                                           @Param("groupName") String groupName);
 
-
     /**
      * query by group name
      * @param groupName groupName
@@ -91,7 +87,8 @@ public interface AlertGroupMapper extends BaseMapper<AlertGroup> {
      * @param alertGroupsIds
      * @return
      */
-    <T> List<AlertGroup> listAuthorizedAlertGroupList (@Param("userId") int userId, @Param("alertGroupsIds")List<Integer> alertGroupsIds);
+    <T> List<AlertGroup> listAuthorizedAlertGroupList(@Param("userId") int userId,
+                                                      @Param("alertGroupsIds") List<Integer> alertGroupsIds);
 
     /**
      * queryAlertGroupPageByIds
@@ -100,5 +97,6 @@ public interface AlertGroupMapper extends BaseMapper<AlertGroup> {
      * @param searchVal
      * @return
      */
-    IPage<AlertGroup> queryAlertGroupPageByIds(Page<AlertGroup> page, @Param("ids") List<Integer> ids, @Param("searchVal") String searchVal);
+    IPage<AlertGroup> queryAlertGroupPageByIds(Page<AlertGroup> page, @Param("ids") List<Integer> ids,
+                                               @Param("searchVal") String searchVal);
 }
