@@ -19,7 +19,15 @@ package org.apache.dolphinscheduler.dao.mapper;
 
 import org.apache.dolphinscheduler.dao.entity.AlertSendStatus;
 
+import org.apache.ibatis.annotations.Param;
+
+import java.util.List;
+
 import com.baomidou.mybatisplus.core.mapper.BaseMapper;
 
 public interface AlertSendStatusMapper extends BaseMapper<AlertSendStatus> {
+
+    int batchInsert(@Param("alertSendStatuses") List<AlertSendStatus> alertSendStatuses);
+
+    void deleteByAlertIds(@Param("alertIds") List<Integer> alertIds);
 }
