@@ -17,12 +17,14 @@
 
 package org.apache.dolphinscheduler.dao.mapper;
 
-import com.baomidou.mybatisplus.core.mapper.BaseMapper;
 import org.apache.dolphinscheduler.dao.entity.FavTask;
+
 import org.apache.ibatis.annotations.Param;
 
 import java.util.Set;
 
+import com.baomidou.mybatisplus.core.mapper.BaseMapper;
+
 /**
  * fav mapper interface
  */
@@ -30,5 +32,5 @@ public interface FavTaskMapper extends BaseMapper<FavTask> {
 
     Set<String> getUserFavTaskTypes(@Param("userId") int userId);
 
-    boolean deleteUserFavTask(@Param("userId") int userId, @Param("taskName") String taskName);
+    boolean deleteUserFavTask(@Param("userId") int userId, @Param("taskType") String taskType);
 }
