@@ -14,34 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+
 package org.apache.dolphinscheduler.dao.mapper;
 
 import org.apache.dolphinscheduler.dao.entity.Session;
 
-import org.apache.ibatis.annotations.Param;
-
-import java.util.List;
-
 import com.baomidou.mybatisplus.core.mapper.BaseMapper;
 
-/**
- * session mapper interface
- */
 public interface SessionMapper extends BaseMapper<Session> {
 
-    /**
-     * query session list by userId
-     * @param userId userId
-     * @return session list
-     */
-    List<Session> queryByUserId(@Param("userId") int userId);
-
-    /**
-     * query session by userId and Ip
-     * @param userId userId
-     * @param ip ip
-     * @return session
-     */
-    Session queryByUserIdAndIp(@Param("userId") int userId, @Param("ip") String ip);
-
 }
