@@ -39,19 +39,14 @@ import com.baomidou.mybatisplus.core.metadata.IPage;
  */
 public interface TaskInstanceMapper extends BaseMapper<TaskInstance> {
 
-    List<TaskInstance> findValidTaskListByProcessId(@Param("processInstanceId") Integer processInstanceId,
-                                                    @Param("flag") Flag flag,
-                                                    @Param("testFlag") int testFlag);
+    List<TaskInstance> findValidTaskListByWorkflowInstanceId(@Param("workflowInstanceId") Integer workflowInstanceId,
+                                                             @Param("flag") Flag flag);
 
-    TaskInstance queryByInstanceIdAndCode(@Param("processInstanceId") int processInstanceId,
+    TaskInstance queryByInstanceIdAndCode(@Param("workflowInstanceId") int workflowInstanceId,
                                           @Param("taskCode") Long taskCode);
 
-    TaskInstance queryByCacheKey(@Param("cacheKey") String cacheKey);
-
-    Boolean clearCacheByCacheKey(@Param("cacheKey") String cacheKey);
-
-    List<TaskInstance> queryByProcessInstanceIdsAndTaskCodes(@Param("processInstanceIds") List<Integer> processInstanceIds,
-                                                             @Param("taskCodes") List<Long> taskCodes);
+    List<TaskInstance> queryByWorkflowInstanceIdsAndTaskCodes(@Param("workflowInstanceIds") List<Integer> workflowInstanceIds,
+                                                              @Param("taskCodes") List<Long> taskCodes);
 
     /**
      * Statistics task instance group by given project codes list by start time
@@ -104,8 +99,8 @@ public interface TaskInstanceMapper extends BaseMapper<TaskInstance> {
 
     IPage<TaskInstance> queryTaskInstanceListPaging(IPage<TaskInstance> page,
                                                     @Param("projectCode") Long projectCode,
-                                                    @Param("processInstanceId") Integer processInstanceId,
-                                                    @Param("processInstanceName") String processInstanceName,
+                                                    @Param("workflowInstanceId") Integer workflowInstanceId,
+                                                    @Param("workflowInstanceName") String workflowInstanceName,
                                                     @Param("searchVal") String searchVal,
                                                     @Param("taskName") String taskName,
                                                     @Param("taskCode") Long taskCode,
@@ -118,7 +113,7 @@ public interface TaskInstanceMapper extends BaseMapper<TaskInstance> {
 
     IPage<TaskInstance> queryStreamTaskInstanceListPaging(IPage<TaskInstance> page,
                                                           @Param("projectCode") Long projectCode,
-                                                          @Param("processDefinitionName") String processDefinitionName,
+                                                          @Param("workflowDefinitionName") String workflowDefinitionName,
                                                           @Param("searchVal") String searchVal,
                                                           @Param("taskName") String taskName,
                                                           @Param("taskCode") Long taskCode,
@@ -137,14 +132,15 @@ public interface TaskInstanceMapper extends BaseMapper<TaskInstance> {
      * find last task instance list in the date interval
      *
      * @param taskCodes taskCodes
-     * @param testFlag testFlag
      * @return task instance list
      */
-    List<TaskInstance> findLastTaskInstances(@Param("processInstanceId") Integer processInstanceId,
-                                             @Param("taskCodes") Set<Long> taskCodes,
-                                             @Param("testFlag") int testFlag);
+    List<TaskInstance> findLastTaskInstances(@Param("workflowInstanceId") Integer workflowInstanceId,
+                                             @Param("taskCodes") Set<Long> taskCodes);
 
-    TaskInstance findLastTaskInstance(@Param("processInstanceId") Integer processInstanceId,
-                                      @Param("taskCode") long depTaskCode,
-                                      @Param("testFlag") int testFlag);
+    TaskInstance findLastTaskInstance(@Param("workflowInstanceId") Integer workflowInstanceId,
+                                      @Param("taskCode") long depTaskCode);
+
+    void updateTaskInstanceState(@Param("taskInstanceId") Integer taskInstanceId,
+                                 @Param("originState") int originState,
+                                 @Param("targetState") int targetState);
 }
