@@ -342,6 +342,27 @@ CREATE TABLE t_ds_command
 -- Records of t_ds_command
 -- ----------------------------
 
+-- ----------------------------
+-- Table structure for t_ds_serial_command
+-- ----------------------------
+DROP TABLE IF EXISTS `t_ds_serial_command`;
+CREATE TABLE `t_ds_serial_command` (
+   `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'primary key',
+   `workflow_definition_code` int(11) NOT NULL COMMENT 'workflow definition code',
+   `workflow_definition_version` int(11) NOT NULL COMMENT 'workflow definition code',
+   `workflow_instance_id` bigint(20) NOT NULL COMMENT 'workflow instance id',
+   `state` tinyint(4) NOT NULL DEFAULT 0 COMMENT 'state of the serial queue: 0 waiting, 1 fired',
+   `command` text COMMENT 'command json',
+   `create_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT 'create time',
+   `update_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'update time',
+   PRIMARY KEY (`id`),
+   KEY `idx_workflow_instance_id` (`workflow_instance_id`)
+);
+
+-- ----------------------------
+-- Table structure for t_ds_serial_command
+-- ----------------------------
+    
 -- ----------------------------
 -- Table structure for t_ds_datasource
 -- ----------------------------
@@ -1061,7 +1082,7 @@ CREATE TABLE t_ds_version
 -- Records of t_ds_version
 -- ----------------------------
 INSERT INTO t_ds_version
-VALUES ('1', '3.3.2');
+VALUES ('1', '3.4.0');
 
 
 -- ----------------------------
