@@ -17,13 +17,6 @@
 
 package org.apache.dolphinscheduler.dao.mapper;
 
-import static org.hamcrest.Matchers.greaterThan;
-import static org.hamcrest.Matchers.greaterThanOrEqualTo;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertThat;
-
 import org.apache.dolphinscheduler.common.utils.DateUtils;
 import org.apache.dolphinscheduler.dao.BaseDaoTest;
 import org.apache.dolphinscheduler.dao.entity.AlertGroup;
@@ -32,8 +25,8 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.springframework.beans.factory.annotation.Autowired;
 
 import com.baomidou.mybatisplus.core.metadata.IPage;
@@ -53,25 +46,22 @@ public class AlertGroupMapperTest extends BaseDaoTest {
     @Test
     public void testInsert() {
         AlertGroup alertGroup = createAlertGroup();
-        assertNotNull(alertGroup);
-        assertThat(alertGroup.getId(), greaterThan(0));
+        Assertions.assertNotNull(alertGroup);
+        Assertions.assertTrue(alertGroup.getId() > 0);
 
     }
 
-
     /**
      * test selectById
      */
     @Test
     public void testSelectById() {
         AlertGroup alertGroup = createAlertGroup();
-        //query
+        // query
         AlertGroup targetAlert = alertGroupMapper.selectById(alertGroup.getId());
-
-        assertEquals(alertGroup, targetAlert);
+        Assertions.assertEquals(alertGroup, targetAlert);
     }
 
-
     /**
      * test page
      */
@@ -93,12 +83,12 @@ public class AlertGroupMapperTest extends BaseDaoTest {
 
         List<AlertGroup> alertGroupList = alertGroupIPage.getRecords();
 
-        assertEquals(alertGroupList.size(), size.intValue());
+        Assertions.assertEquals(alertGroupList.size(), size.intValue());
 
         for (AlertGroup alertGroup : alertGroupList) {
             AlertGroup resultAlertGroup = alertGroupMap.get(alertGroup.getId());
             if (resultAlertGroup != null) {
-                assertEquals(alertGroup, resultAlertGroup);
+                Assertions.assertEquals(alertGroup, resultAlertGroup);
             }
         }
 
@@ -119,10 +109,9 @@ public class AlertGroupMapperTest extends BaseDaoTest {
 
         AlertGroup resultAlertGroup = alertGroupMapper.selectById(alertGroup.getId());
 
-        assertEquals(alertGroup, resultAlertGroup);
+        Assertions.assertEquals(alertGroup, resultAlertGroup);
     }
 
-
     /**
      * test delete
      */
@@ -135,10 +124,9 @@ public class AlertGroupMapperTest extends BaseDaoTest {
 
         AlertGroup resultAlertGroup = alertGroupMapper.selectById(alertGroup.getId());
 
-        assertNull(resultAlertGroup);
+        Assertions.assertNull(resultAlertGroup);
     }
 
-
     /**
      * test query by groupname
      */
@@ -159,7 +147,7 @@ public class AlertGroupMapperTest extends BaseDaoTest {
         String groupName = "testGroup";
         createAlertGroups(1, groupName);
 
-        Assert.assertTrue(alertGroupMapper.existGroupName(groupName));
+        Assertions.assertTrue(alertGroupMapper.existGroupName(groupName));
     }
 
     /**
@@ -185,12 +173,12 @@ public class AlertGroupMapperTest extends BaseDaoTest {
     private void compareAlertGroups(Map<Integer, AlertGroup> alertGroupMap,
                                     List<AlertGroup> alertGroupList) {
         // greaterThanOrEqualTo，beacuse maybe db have already exists
-        assertThat(alertGroupList.size(), greaterThanOrEqualTo(alertGroupMap.size()));
+        Assertions.assertTrue(alertGroupList.size() >= alertGroupMap.size());
 
         for (AlertGroup alertGroup : alertGroupList) {
             AlertGroup resultAlertGroup = alertGroupMap.get(alertGroup.getId());
             if (resultAlertGroup != null) {
-                assertEquals(alertGroup, resultAlertGroup);
+                Assertions.assertEquals(alertGroup, resultAlertGroup);
             }
         }
     }
@@ -239,7 +227,7 @@ public class AlertGroupMapperTest extends BaseDaoTest {
      * @return AlertGroup map
      */
     private Map<Integer, AlertGroup> createAlertGroups(
-        Integer count, String groupName) {
+                                                       Integer count, String groupName) {
         Map<Integer, AlertGroup> alertGroupMap = new HashMap<>();
 
         AlertGroup alertGroup = null;
@@ -257,8 +245,7 @@ public class AlertGroupMapperTest extends BaseDaoTest {
      * @param count create AlertGroup count
      * @return AlertGroup map
      */
-    private Map<Integer, AlertGroup> createAlertGroups(
-        Integer count) {
+    private Map<Integer, AlertGroup> createAlertGroups(Integer count) {
         Map<Integer, AlertGroup> alertGroupMap = new HashMap<>();
 
         AlertGroup alertGroup = null;
@@ -270,4 +257,4 @@ public class AlertGroupMapperTest extends BaseDaoTest {
         return alertGroupMap;
     }
 
-}
\ No newline at end of file
+}
