@@ -17,49 +17,49 @@
 
 package org.apache.dolphinscheduler.plugin.datasource.api.plugin;
 
-import org.apache.dolphinscheduler.spi.datasource.DataSourceChannel;
-import org.apache.dolphinscheduler.spi.datasource.DataSourceChannelFactory;
-import org.apache.dolphinscheduler.spi.plugin.PrioritySPIFactory;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
-
-import java.util.Collections;
-import java.util.Map;
-import java.util.ServiceLoader;
-import java.util.concurrent.ConcurrentHashMap;
-
 import static java.lang.String.format;
 
+import org.apache.dolphinscheduler.spi.datasource.DataSourceChannel;
+import org.apache.dolphinscheduler.spi.datasource.DataSourceChannelFactory;
+import org.apache.dolphinscheduler.spi.enums.DbType;
+import org.apache.dolphinscheduler.spi.plugin.PrioritySPIFactory;
+
+import java.util.Map;
+import java.util.concurrent.ConcurrentHashMap;
+
+import lombok.extern.slf4j.Slf4j;
+
+@Slf4j
 public class DataSourcePluginManager {
-    private static final Logger logger = LoggerFactory.getLogger(DataSourcePluginManager.class);
 
-    private final Map<String, DataSourceChannel> datasourceClientMap = new ConcurrentHashMap<>();
+    private final Map<String, DataSourceChannel> datasourceChannelMap = new ConcurrentHashMap<>();
 
-    public Map<String, DataSourceChannel> getDataSourceChannelMap() {
-        return Collections.unmodifiableMap(datasourceClientMap);
+    public DataSourceChannel getDataSourceChannel(final DbType dbType) {
+        return datasourceChannelMap.get(dbType.getName());
     }
 
     public void installPlugin() {
 
-        PrioritySPIFactory<DataSourceChannelFactory> prioritySPIFactory = new PrioritySPIFactory<>(DataSourceChannelFactory.class);
+        PrioritySPIFactory<DataSourceChannelFactory> prioritySPIFactory =
+                new PrioritySPIFactory<>(DataSourceChannelFactory.class);
         for (Map.Entry<String, DataSourceChannelFactory> entry : prioritySPIFactory.getSPIMap().entrySet()) {
             final DataSourceChannelFactory factory = entry.getValue();
             final String name = entry.getKey();
 
-            logger.info("Registering datasource plugin: {}", name);
+            log.info("Registering datasource plugin: {}", name);
 
-            if (datasourceClientMap.containsKey(name)) {
+            if (datasourceChannelMap.containsKey(name)) {
                 throw new IllegalStateException(format("Duplicate datasource plugins named '%s'", name));
             }
 
             loadDatasourceClient(factory);
 
-            logger.info("Registered datasource plugin: {}", name);
+            log.info("Registered datasource plugin: {}", name);
         }
     }
 
     private void loadDatasourceClient(DataSourceChannelFactory datasourceChannelFactory) {
         DataSourceChannel datasourceChannel = datasourceChannelFactory.create();
-        datasourceClientMap.put(datasourceChannelFactory.getName(), datasourceChannel);
+        datasourceChannelMap.put(datasourceChannelFactory.getName(), datasourceChannel);
     }
 }
