@@ -1,20 +1,18 @@
 /*
- * Licensed to Apache Software Foundation (ASF) under one or more contributor
- * license agreements. See the NOTICE file distributed with
- * this work for additional information regarding copyright
- * ownership. Apache Software Foundation (ASF) licenses this file to you under
- * the Apache License, Version 2.0 (the "License"); you may
- * not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *    http://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.dolphinscheduler.e2e.cases;
@@ -26,16 +24,19 @@ import org.apache.dolphinscheduler.e2e.pages.LoginPage;
 import org.apache.dolphinscheduler.e2e.pages.security.SecurityPage;
 import org.apache.dolphinscheduler.e2e.pages.security.TenantPage;
 
-import org.testcontainers.shaded.org.awaitility.Awaitility;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Order;
 import org.junit.jupiter.api.Test;
+import org.junitpioneer.jupiter.DisableIfTestFails;
 import org.openqa.selenium.By;
 import org.openqa.selenium.WebElement;
 import org.openqa.selenium.remote.RemoteWebDriver;
+import org.testcontainers.shaded.org.awaitility.Awaitility;
 
 @DolphinScheduler(composeFiles = "docker/basic/docker-compose.yaml")
+@DisableIfTestFails
 class TenantE2ETest {
+
     private static final String tenant = System.getProperty("user.name");
     private static final String editDescription = "This is a test";
 
@@ -44,10 +45,9 @@ class TenantE2ETest {
     @BeforeAll
     public static void setup() {
         new LoginPage(browser)
-            .login("admin", "dolphinscheduler123")
-            .goToNav(SecurityPage.class)
-            .goToTab(TenantPage.class)
-        ;
+                .login("admin", "dolphinscheduler123")
+                .goToNav(SecurityPage.class)
+                .goToTab(TenantPage.class);
     }
 
     @Test
@@ -57,9 +57,9 @@ class TenantE2ETest {
         page.create(tenant);
 
         Awaitility.await().untilAsserted(() -> assertThat(page.tenantList())
-            .as("Tenant list should contain newly-created tenant")
-            .extracting(WebElement::getText)
-            .anyMatch(it -> it.contains(tenant)));
+                .as("Tenant list should contain newly-created tenant")
+                .extracting(WebElement::getText)
+                .anyMatch(it -> it.contains(tenant)));
     }
 
     @Test
@@ -69,10 +69,8 @@ class TenantE2ETest {
 
         page.create(tenant);
 
-        Awaitility.await().untilAsserted(() ->
-            assertThat(browser.findElement(By.tagName("body")).getText())
-                .contains("already exists")
-        );
+        Awaitility.await().untilAsserted(() -> assertThat(browser.findElement(By.tagName("body")).getText())
+                .contains("already exists"));
 
         page.tenantForm().buttonCancel().click();
     }
@@ -87,9 +85,9 @@ class TenantE2ETest {
         Awaitility.await().untilAsserted(() -> {
             browser.navigate().refresh();
             assertThat(page.tenantList())
-                .as("Tenant list should contain newly-modified tenant")
-                .extracting(WebElement::getText)
-                .anyMatch(it -> it.contains(tenant));
+                    .as("Tenant list should contain newly-modified tenant")
+                    .extracting(WebElement::getText)
+                    .anyMatch(it -> it.contains(tenant));
         });
     }
 
@@ -103,10 +101,8 @@ class TenantE2ETest {
             browser.navigate().refresh();
 
             assertThat(
-                page.tenantList()
-            ).noneMatch(
-                it -> it.getText().contains(tenant)
-            );
+                    page.tenantList()).noneMatch(
+                            it -> it.getText().contains(tenant));
         });
     }
 }
