@@ -1,22 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
- *   http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
+ *    http://www.apache.org/licenses/LICENSE-2.0
  *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
+
 package org.apache.dolphinscheduler.e2e.pages.project.workflow;
 
 import static org.assertj.core.api.Assertions.assertThat;
@@ -27,6 +25,8 @@ import org.apache.dolphinscheduler.e2e.pages.project.ProjectDetailPage;
 import java.util.List;
 import java.util.stream.Collectors;
 
+import lombok.Getter;
+
 import org.openqa.selenium.By;
 import org.openqa.selenium.JavascriptExecutor;
 import org.openqa.selenium.WebElement;
@@ -35,12 +35,11 @@ import org.openqa.selenium.support.FindBy;
 import org.openqa.selenium.support.FindBys;
 import org.testcontainers.shaded.org.awaitility.Awaitility;
 
-import lombok.Getter;
-
 @Getter
 public final class WorkflowDefinitionTab extends NavBarPage implements ProjectDetailPage.Tab {
-    @FindBy(className = "btn-create-process")
-    private WebElement buttonCreateProcess;
+
+    @FindBy(className = "btn-create-workflow")
+    private WebElement buttonCreateWorkflow;
 
     @FindBys({
             @FindBy(className = "btn-selected"),
@@ -60,12 +59,6 @@ public final class WorkflowDefinitionTab extends NavBarPage implements ProjectDe
     })
     private WebElement buttonConfirm;
 
-    @FindBys({
-        @FindBy(className = "n-dialog__action"),
-        @FindBy(className = "n-button--default-type"),
-    })
-    private WebElement publishSuccessButtonCancel;
-
     @FindBy(className = "items")
     private List<WebElement> workflowList;
 
@@ -77,13 +70,13 @@ public final class WorkflowDefinitionTab extends NavBarPage implements ProjectDe
     }
 
     public WorkflowForm createWorkflow() {
-        buttonCreateProcess().click();
+        buttonCreateWorkflow().click();
 
         return new WorkflowForm(driver);
     }
 
-    public WorkflowForm createSubProcessWorkflow() {
-        buttonCreateProcess().click();
+    public WorkflowForm createSubWorkflowTask() {
+        buttonCreateWorkflow().click();
         subProcessList().click();
 
         return new WorkflowForm(driver);
@@ -91,30 +84,28 @@ public final class WorkflowDefinitionTab extends NavBarPage implements ProjectDe
 
     public WorkflowDefinitionTab publish(String workflow) {
         workflowList()
-            .stream()
-            .filter(it -> it.findElement(By.className("workflow-name")).getAttribute("innerText").equals(workflow))
-            .flatMap(it -> it.findElements(By.className("btn-publish")).stream())
-            .filter(WebElement::isDisplayed)
-            .findFirst()
-            .orElseThrow(() -> new RuntimeException("Can not find publish button in workflow definition"))
-            .click();
+                .stream()
+                .filter(it -> it.findElement(By.className("workflow-name")).getAttribute("innerText").equals(workflow))
+                .flatMap(it -> it.findElements(By.className("btn-publish")).stream())
+                .filter(WebElement::isDisplayed)
+                .findFirst()
+                .orElseThrow(() -> new RuntimeException("Can not find publish button in workflow definition"))
+                .click();
 
-        ((JavascriptExecutor) driver).executeScript("arguments[0].click();", buttonConfirm());
-
-        ((JavascriptExecutor) driver).executeScript("arguments[0].click();", publishSuccessButtonCancel());
+        driver.executeScript("arguments[0].click();", buttonConfirm());
 
         return this;
     }
 
     public WorkflowRunDialog run(String workflow) {
         workflowList()
-            .stream()
-            .filter(it -> it.findElement(By.className("workflow-name")).getAttribute("innerText").equals(workflow))
-            .flatMap(it -> it.findElements(By.className("btn-run")).stream())
-            .filter(WebElement::isDisplayed)
-            .findFirst()
-            .orElseThrow(() -> new RuntimeException("Can not find run button in workflow definition"))
-            .click();
+                .stream()
+                .filter(it -> it.findElement(By.className("workflow-name")).getAttribute("innerText").equals(workflow))
+                .flatMap(it -> it.findElements(By.className("btn-run")).stream())
+                .filter(WebElement::isDisplayed)
+                .findFirst()
+                .orElseThrow(() -> new RuntimeException("Can not find run button in workflow definition"))
+                .click();
 
         return new WorkflowRunDialog(this);
     }
@@ -136,19 +127,18 @@ public final class WorkflowDefinitionTab extends NavBarPage implements ProjectDe
 
     public WorkflowDefinitionTab delete(String workflow) {
         Awaitility.await().untilAsserted(() -> assertThat(workflowList())
-            .as("Workflow list should contain newly-created workflow")
-            .anyMatch(
-                it -> it.getText().contains(workflow)
-            ));
+                .as("Workflow list should contain newly-created workflow")
+                .anyMatch(
+                        it -> it.getText().contains(workflow)));
 
         workflowList()
-            .stream()
-            .filter(it -> it.findElement(By.className("workflow-name")).getAttribute("innerText").equals(workflow))
-            .flatMap(it -> it.findElements(By.className("btn-delete")).stream())
-            .filter(WebElement::isDisplayed)
-            .findFirst()
-            .orElseThrow(() -> new RuntimeException("Can not find delete button in workflow definition"))
-            .click();
+                .stream()
+                .filter(it -> it.findElement(By.className("workflow-name")).getAttribute("innerText").equals(workflow))
+                .flatMap(it -> it.findElements(By.className("btn-delete")).stream())
+                .filter(WebElement::isDisplayed)
+                .findFirst()
+                .orElseThrow(() -> new RuntimeException("Can not find delete button in workflow definition"))
+                .click();
 
         return this;
     }
