@@ -1,33 +1,36 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
- *   http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing,
- * software distributed under the License is distributed on an
- * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
- * KIND, either express or implied.  See the License for the
- * specific language governing permissions and limitations
- * under the License.
+ *    http://www.apache.org/licenses/LICENSE-2.0
  *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
+
 package org.apache.dolphinscheduler.e2e.pages.project.workflow;
 
+import org.apache.dolphinscheduler.e2e.core.WebDriverWaitFactory;
+import org.apache.dolphinscheduler.e2e.pages.project.workflow.task.HttpTaskForm;
+import org.apache.dolphinscheduler.e2e.pages.project.workflow.task.JavaTaskForm;
+import org.apache.dolphinscheduler.e2e.pages.project.workflow.task.PythonTaskForm;
 import org.apache.dolphinscheduler.e2e.pages.project.workflow.task.ShellTaskForm;
 import org.apache.dolphinscheduler.e2e.pages.project.workflow.task.SubWorkflowTaskForm;
+import org.apache.dolphinscheduler.e2e.pages.project.workflow.task.SwitchTaskForm;
 
 import java.nio.charset.StandardCharsets;
-import java.time.Duration;
 import java.util.List;
-import java.util.concurrent.TimeUnit;
 
-import org.apache.dolphinscheduler.e2e.pages.project.workflow.task.SwitchTaskForm;
+import lombok.Getter;
+import lombok.SneakyThrows;
+
 import org.openqa.selenium.By;
 import org.openqa.selenium.JavascriptExecutor;
 import org.openqa.selenium.WebDriver;
@@ -35,17 +38,14 @@ import org.openqa.selenium.WebElement;
 import org.openqa.selenium.interactions.Actions;
 import org.openqa.selenium.support.FindBy;
 import org.openqa.selenium.support.PageFactory;
+import org.openqa.selenium.support.ui.ExpectedConditions;
 
 import com.google.common.io.Resources;
 
-import lombok.Getter;
-import lombok.SneakyThrows;
-import org.openqa.selenium.support.ui.ExpectedConditions;
-import org.openqa.selenium.support.ui.WebDriverWait;
-
 @SuppressWarnings("UnstableApiUsage")
 @Getter
 public final class WorkflowForm {
+
     private WebDriver driver;
     private final WorkflowSaveDialog saveForm;
     private final WorkflowFormatDialog formatDialog;
@@ -74,21 +74,30 @@ public final class WorkflowForm {
         final String dragAndDrop = String.join("\n",
                 Resources.readLines(Resources.getResource("dragAndDrop.js"), StandardCharsets.UTF_8));
         js.executeScript(dragAndDrop, task, canvas);
+        WebDriverWaitFactory.createWebDriverWait(driver).until(ExpectedConditions
+                .visibilityOfElementLocated(By.xpath("//*[contains(text(), 'Current node settings')]")));
 
         switch (type) {
             case SHELL:
                 return (T) new ShellTaskForm(this);
-            case SUB_PROCESS:
+            case SUB_WORKFLOW:
                 return (T) new SubWorkflowTaskForm(this);
             case SWITCH:
                 return (T) new SwitchTaskForm(this);
+            case HTTP:
+                return (T) new HttpTaskForm(this);
+            case JAVA:
+                return (T) new JavaTaskForm(this);
+            case PYTHON:
+                return (T) new PythonTaskForm(this);
         }
         throw new UnsupportedOperationException("Unknown task type");
     }
 
     public WebElement getTask(String taskName) {
-        List<WebElement> tasks = new WebDriverWait(driver, Duration.ofSeconds(20))
-                .until(ExpectedConditions.visibilityOfAllElementsLocatedBy(By.cssSelector("svg > g > g[class^='x6-graph-svg-stage'] > g[data-shape^='dag-task']")));
+        List<WebElement> tasks = WebDriverWaitFactory.createWebDriverWait(driver)
+                .until(ExpectedConditions.visibilityOfAllElementsLocatedBy(
+                        By.cssSelector("svg > g > g[class^='x6-graph-svg-stage'] > g[data-shape^='dag-task']")));
 
         WebElement task = tasks.stream()
                 .filter(t -> t.getText().contains(taskName))
@@ -103,7 +112,8 @@ public final class WorkflowForm {
 
     public WorkflowSaveDialog submit() {
         buttonSave().click();
-
+        WebDriverWaitFactory.createWebDriverWait(driver)
+                .until(ExpectedConditions.visibilityOfElementLocated(By.xpath("//*[contains(.,'Basic Information')]")));
         return new WorkflowSaveDialog(this);
     }
 
@@ -115,7 +125,10 @@ public final class WorkflowForm {
 
     public enum TaskType {
         SHELL,
-        SUB_PROCESS,
+        SUB_WORKFLOW,
         SWITCH,
+        HTTP,
+        JAVA,
+        PYTHON
     }
 }
