@@ -17,12 +17,8 @@
 
 package org.apache.dolphinscheduler.plugin.registry.jdbc;
 
-import org.apache.dolphinscheduler.plugin.registry.jdbc.mapper.JdbcRegistryClientHeartbeatMapper;
-import org.apache.dolphinscheduler.plugin.registry.jdbc.mapper.JdbcRegistryDataChanceEventMapper;
-import org.apache.dolphinscheduler.plugin.registry.jdbc.mapper.JdbcRegistryDataMapper;
-import org.apache.dolphinscheduler.plugin.registry.jdbc.mapper.JdbcRegistryLockMapper;
 import org.apache.dolphinscheduler.plugin.registry.jdbc.repository.JdbcRegistryClientRepository;
-import org.apache.dolphinscheduler.plugin.registry.jdbc.repository.JdbcRegistryDataChanceEventRepository;
+import org.apache.dolphinscheduler.plugin.registry.jdbc.repository.JdbcRegistryDataChangeEventRepository;
 import org.apache.dolphinscheduler.plugin.registry.jdbc.repository.JdbcRegistryDataRepository;
 import org.apache.dolphinscheduler.plugin.registry.jdbc.repository.JdbcRegistryLockRepository;
 import org.apache.dolphinscheduler.plugin.registry.jdbc.server.IJdbcRegistryServer;
@@ -30,6 +26,8 @@ import org.apache.dolphinscheduler.plugin.registry.jdbc.server.JdbcRegistryServe
 
 import org.apache.ibatis.session.SqlSessionFactory;
 
+import javax.sql.DataSource;
+
 import lombok.extern.slf4j.Slf4j;
 
 import org.mybatis.spring.SqlSessionTemplate;
@@ -40,6 +38,9 @@ import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
 import org.springframework.context.annotation.Bean;
 import org.springframework.context.annotation.ComponentScan;
 import org.springframework.context.annotation.Configuration;
+import org.springframework.jdbc.datasource.DataSourceTransactionManager;
+import org.springframework.transaction.PlatformTransactionManager;
+import org.springframework.transaction.support.TransactionTemplate;
 
 import com.baomidou.mybatisplus.autoconfigure.MybatisPlusAutoConfiguration;
 import com.baomidou.mybatisplus.extension.spring.MybatisSqlSessionFactoryBean;
@@ -61,14 +62,16 @@ public class JdbcRegistryAutoConfiguration {
     public IJdbcRegistryServer jdbcRegistryServer(JdbcRegistryDataRepository jdbcRegistryDataRepository,
                                                   JdbcRegistryLockRepository jdbcRegistryLockRepository,
                                                   JdbcRegistryClientRepository jdbcRegistryClientRepository,
-                                                  JdbcRegistryDataChanceEventRepository jdbcRegistryDataChanceEventRepository,
-                                                  JdbcRegistryProperties jdbcRegistryProperties) {
+                                                  JdbcRegistryDataChangeEventRepository jdbcRegistryDataChangeEventRepository,
+                                                  JdbcRegistryProperties jdbcRegistryProperties,
+                                                  TransactionTemplate jdbcTransactionTemplate) {
         return new JdbcRegistryServer(
                 jdbcRegistryDataRepository,
                 jdbcRegistryLockRepository,
                 jdbcRegistryClientRepository,
-                jdbcRegistryDataChanceEventRepository,
-                jdbcRegistryProperties);
+                jdbcRegistryDataChangeEventRepository,
+                jdbcRegistryProperties,
+                jdbcTransactionTemplate);
     }
 
     @Bean
@@ -81,42 +84,38 @@ public class JdbcRegistryAutoConfiguration {
 
     @Bean
     @ConditionalOnMissingBean
-    public SqlSessionFactory sqlSessionFactory(JdbcRegistryProperties jdbcRegistryProperties) throws Exception {
-        log.info("Initialize jdbcRegistrySqlSessionFactory");
+    public DataSource jdbcRegistryDataSource(JdbcRegistryProperties jdbcRegistryProperties) {
+        return new HikariDataSource(jdbcRegistryProperties.getHikariConfig());
+    }
+
+    @Bean
+    @ConditionalOnMissingBean
+    public PlatformTransactionManager jdbcRegistryTransactionManager(DataSource jdbcRegistryDataSource) {
+        DataSourceTransactionManager transactionManager = new DataSourceTransactionManager();
+        transactionManager.setDataSource(jdbcRegistryDataSource);
+        return transactionManager;
+    }
+
+    @Bean
+    @ConditionalOnMissingBean
+    public TransactionTemplate jdbcTransactionTemplate(PlatformTransactionManager jdbcRegistryTransactionManager) {
+        TransactionTemplate transactionTemplate = new TransactionTemplate();
+        transactionTemplate.setTransactionManager(jdbcRegistryTransactionManager);
+        return transactionTemplate;
+    }
+
+    @Bean
+    @ConditionalOnMissingBean
+    public SqlSessionFactory jdbcRegistrySqlSessionFactory(DataSource jdbcRegistryDataSource) throws Exception {
         MybatisSqlSessionFactoryBean sqlSessionFactoryBean = new MybatisSqlSessionFactoryBean();
-        sqlSessionFactoryBean.setDataSource(new HikariDataSource(jdbcRegistryProperties.getHikariConfig()));
+        sqlSessionFactoryBean.setDataSource(jdbcRegistryDataSource);
         return sqlSessionFactoryBean.getObject();
     }
 
     @Bean
     @ConditionalOnMissingBean
-    public SqlSessionTemplate sqlSessionTemplate(SqlSessionFactory jdbcRegistrySqlSessionFactory) {
-        log.info("Initialize jdbcRegistrySqlSessionTemplate");
+    public SqlSessionTemplate jdbcRegistrySqlSessionTemplate(SqlSessionFactory jdbcRegistrySqlSessionFactory) {
         return new SqlSessionTemplate(jdbcRegistrySqlSessionFactory);
     }
 
-    @Bean
-    public JdbcRegistryDataMapper jdbcRegistryDataMapper(SqlSessionTemplate jdbcRegistrySqlSessionTemplate) {
-        jdbcRegistrySqlSessionTemplate.getConfiguration().addMapper(JdbcRegistryDataMapper.class);
-        return jdbcRegistrySqlSessionTemplate.getMapper(JdbcRegistryDataMapper.class);
-    }
-
-    @Bean
-    public JdbcRegistryLockMapper jdbcRegistryLockMapper(SqlSessionTemplate jdbcRegistrySqlSessionTemplate) {
-        jdbcRegistrySqlSessionTemplate.getConfiguration().addMapper(JdbcRegistryLockMapper.class);
-        return jdbcRegistrySqlSessionTemplate.getMapper(JdbcRegistryLockMapper.class);
-    }
-
-    @Bean
-    public JdbcRegistryDataChanceEventMapper jdbcRegistryDataChanceEventMapper(SqlSessionTemplate jdbcRegistrySqlSessionTemplate) {
-        jdbcRegistrySqlSessionTemplate.getConfiguration().addMapper(JdbcRegistryDataChanceEventMapper.class);
-        return jdbcRegistrySqlSessionTemplate.getMapper(JdbcRegistryDataChanceEventMapper.class);
-    }
-
-    @Bean
-    public JdbcRegistryClientHeartbeatMapper jdbcRegistryClientHeartbeatMapper(SqlSessionTemplate jdbcRegistrySqlSessionTemplate) {
-        jdbcRegistrySqlSessionTemplate.getConfiguration().addMapper(JdbcRegistryClientHeartbeatMapper.class);
-        return jdbcRegistrySqlSessionTemplate.getMapper(JdbcRegistryClientHeartbeatMapper.class);
-    }
-
 }
