@@ -17,16 +17,15 @@
 
 package org.apache.dolphinscheduler.spi.params.base;
 
-import static org.apache.dolphinscheduler.spi.utils.Constants.STRING_PLUGIN_PARAM_EMIT;
-import static org.apache.dolphinscheduler.spi.utils.Constants.STRING_PLUGIN_PARAM_FIELD;
-import static org.apache.dolphinscheduler.spi.utils.Constants.STRING_PLUGIN_PARAM_NAME;
-import static org.apache.dolphinscheduler.spi.utils.Constants.STRING_PLUGIN_PARAM_PROPS;
-import static org.apache.dolphinscheduler.spi.utils.Constants.STRING_PLUGIN_PARAM_TITLE;
-import static org.apache.dolphinscheduler.spi.utils.Constants.STRING_PLUGIN_PARAM_TYPE;
-import static org.apache.dolphinscheduler.spi.utils.Constants.STRING_PLUGIN_PARAM_VALIDATE;
-import static org.apache.dolphinscheduler.spi.utils.Constants.STRING_PLUGIN_PARAM_VALUE;
-
 import static java.util.Objects.requireNonNull;
+import static org.apache.dolphinscheduler.common.constants.Constants.STRING_PLUGIN_PARAM_EMIT;
+import static org.apache.dolphinscheduler.common.constants.Constants.STRING_PLUGIN_PARAM_FIELD;
+import static org.apache.dolphinscheduler.common.constants.Constants.STRING_PLUGIN_PARAM_NAME;
+import static org.apache.dolphinscheduler.common.constants.Constants.STRING_PLUGIN_PARAM_PROPS;
+import static org.apache.dolphinscheduler.common.constants.Constants.STRING_PLUGIN_PARAM_TITLE;
+import static org.apache.dolphinscheduler.common.constants.Constants.STRING_PLUGIN_PARAM_TYPE;
+import static org.apache.dolphinscheduler.common.constants.Constants.STRING_PLUGIN_PARAM_VALIDATE;
+import static org.apache.dolphinscheduler.common.constants.Constants.STRING_PLUGIN_PARAM_VALUE;
 
 import java.util.List;
 
@@ -118,7 +117,8 @@ public class PluginParams {
 
     @JsonPOJOBuilder(buildMethodName = "build", withPrefix = "set")
     public static class Builder {
-        //Must have
+
+        // Must have
         protected String name;
 
         protected FormType formType;
@@ -127,7 +127,7 @@ public class PluginParams {
 
         protected String fieldName;
 
-        //option params
+        // option params
         protected ParamsProps props;
 
         protected Object value;
@@ -154,7 +154,7 @@ public class PluginParams {
             this.fieldName = title;
         }
 
-        //for json deserialize to POJO
+        // for json deserialize to POJO
         @JsonCreator
         public Builder(@JsonProperty("field") String name,
                        @JsonProperty("type") FormType formType,
@@ -166,8 +166,7 @@ public class PluginParams {
                        @JsonProperty("emit") List<String> emit,
                        @JsonProperty("info") String info,
                        @JsonProperty("hidden") Boolean hidden,
-                       @JsonProperty("display") Boolean display
-        ) {
+                       @JsonProperty("display") Boolean display) {
             requireNonNull(name, "name is null");
             requireNonNull(formType, "formType is null");
             requireNonNull(title, "title is null");
@@ -222,5 +221,3 @@ public class PluginParams {
     }
 
 }
-
-
