@@ -23,8 +23,6 @@ import org.apache.dolphinscheduler.plugin.task.api.model.TaskAlertInfo;
 import org.apache.dolphinscheduler.plugin.task.api.parameters.AbstractParameters;
 
 import java.util.Map;
-import java.util.StringJoiner;
-import java.util.concurrent.LinkedBlockingQueue;
 import java.util.regex.Matcher;
 
 import lombok.Getter;
@@ -149,20 +147,6 @@ public abstract class AbstractTask {
         return TaskExecutionStatus.FAILURE;
     }
 
-    /**
-     * log handle
-     *
-     * @param logs log list
-     */
-    public void logHandle(LinkedBlockingQueue<String> logs) {
-
-        StringJoiner joiner = new StringJoiner("\n\t");
-        while (!logs.isEmpty()) {
-            joiner.add(logs.poll());
-        }
-        log.info(" -> {}", joiner);
-    }
-
     /**
      * regular expressions match the contents between two specified strings
      *
