@@ -24,6 +24,7 @@ import com.alibaba.druid.sql.dialect.hive.parser.HiveStatementParser;
 import com.alibaba.druid.sql.dialect.mysql.parser.MySqlStatementParser;
 import com.alibaba.druid.sql.dialect.oracle.parser.OracleStatementParser;
 import com.alibaba.druid.sql.dialect.postgresql.parser.PGSQLStatementParser;
+import com.alibaba.druid.sql.dialect.presto.parser.PrestoStatementParser;
 import com.alibaba.druid.sql.dialect.sqlserver.parser.SQLServerStatementParser;
 import com.alibaba.druid.sql.parser.SQLStatementParser;
 
@@ -41,6 +42,8 @@ public class DataxUtils {
 
     public static final String DATAX_READER_PLUGIN_RDBMS = "rdbmsreader";
 
+    public static final String DATAX_READER_PLUGIN_OCEANBASE = "oceanbasev10reader";
+
     public static final String DATAX_WRITER_PLUGIN_MYSQL = "mysqlwriter";
 
     public static final String DATAX_WRITER_PLUGIN_POSTGRESQL = "postgresqlwriter";
@@ -50,9 +53,12 @@ public class DataxUtils {
     public static final String DATAX_WRITER_PLUGIN_SQLSERVER = "sqlserverwriter";
 
     public static final String DATAX_WRITER_PLUGIN_CLICKHOUSE = "clickhousewriter";
+    public static final String DATAX_WRITER_PLUGIN_DATABEND = "databendwriter";
 
     public static final String DATAX_WRITER_PLUGIN_RDBMS = "rdbmswriter";
 
+    public static final String DATAX_WRITER_PLUGIN_OCEANBASE = "oceanbasev10writer";
+
     public static String getReaderPluginName(DbType dbType) {
         switch (dbType) {
             case MYSQL:
@@ -65,7 +71,10 @@ public class DataxUtils {
                 return DATAX_READER_PLUGIN_SQLSERVER;
             case CLICKHOUSE:
                 return DATAX_READER_PLUGIN_CLICKHOUSE;
+            case OCEANBASE:
+                return DATAX_READER_PLUGIN_OCEANBASE;
             case HIVE:
+            case PRESTO:
             default:
                 return DATAX_READER_PLUGIN_RDBMS;
         }
@@ -83,7 +92,12 @@ public class DataxUtils {
                 return DATAX_WRITER_PLUGIN_SQLSERVER;
             case CLICKHOUSE:
                 return DATAX_WRITER_PLUGIN_CLICKHOUSE;
+            case DATABEND:
+                return DATAX_WRITER_PLUGIN_DATABEND;
+            case OCEANBASE:
+                return DATAX_WRITER_PLUGIN_OCEANBASE;
             case HIVE:
+            case PRESTO:
             default:
                 return DATAX_WRITER_PLUGIN_RDBMS;
         }
@@ -103,11 +117,20 @@ public class DataxUtils {
                 return new ClickhouseStatementParser(sql);
             case HIVE:
                 return new HiveStatementParser(sql);
+            case PRESTO:
+                return new PrestoStatementParser(sql);
             default:
                 return null;
         }
     }
 
+    public static SQLStatementParser getSqlStatementParser(String compatibleMode, String sql) {
+        if (compatibleMode.toLowerCase().equals(DbType.ORACLE.getName())) {
+            return new OracleStatementParser(sql);
+        }
+        return new MySqlStatementParser(sql);
+    }
+
     public static String[] convertKeywordsColumns(DbType dbType, String[] columns) {
         if (columns == null) {
             return null;
@@ -139,6 +162,12 @@ public class DataxUtils {
             case ORACLE:
                 return String.format("\"%s\"", column);
             case SQLSERVER:
+                return String.format("\"%s\"", column);
+            case CLICKHOUSE:
+                return String.format("`%s`", column);
+            case DATABEND:
+                return String.format("`%s`", column);
+            case OCEANBASE:
                 return String.format("`%s`", column);
             default:
                 return column;
