@@ -17,27 +17,19 @@
 
 package org.apache.dolphinscheduler.plugin.task.dinky;
 
-import com.google.auto.service.AutoService;
-
 import org.apache.dolphinscheduler.plugin.task.api.TaskChannel;
 import org.apache.dolphinscheduler.plugin.task.api.TaskChannelFactory;
-import org.apache.dolphinscheduler.spi.params.base.PluginParams;
 
-import java.util.ArrayList;
-import java.util.List;
+import com.google.auto.service.AutoService;
 
 @AutoService(TaskChannelFactory.class)
 public class DinkyTaskChannelFactory implements TaskChannelFactory {
+
     @Override
     public String getName() {
         return "DINKY";
     }
 
-    @Override
-    public List<PluginParams> getParams() {
-        return new ArrayList<>();
-    }
-
     @Override
     public TaskChannel create() {
         return new DinkyTaskChannel();
