@@ -19,9 +19,6 @@ package org.apache.dolphinscheduler.plugin.task.procedure;
 
 import org.apache.dolphinscheduler.plugin.task.api.TaskChannel;
 import org.apache.dolphinscheduler.plugin.task.api.TaskChannelFactory;
-import org.apache.dolphinscheduler.spi.params.base.PluginParams;
-
-import java.util.List;
 
 import com.google.auto.service.AutoService;
 
@@ -33,11 +30,6 @@ public class ProcedureTaskChannelFactory implements TaskChannelFactory {
         return "PROCEDURE";
     }
 
-    @Override
-    public List<PluginParams> getParams() {
-        return null;
-    }
-
     @Override
     public TaskChannel create() {
         return new ProcedureTaskChannel();
