@@ -21,29 +21,17 @@ import org.apache.dolphinscheduler.common.utils.JSONUtils;
 import org.apache.dolphinscheduler.plugin.task.api.TaskChannel;
 import org.apache.dolphinscheduler.plugin.task.api.TaskExecutionContext;
 import org.apache.dolphinscheduler.plugin.task.api.parameters.AbstractParameters;
-import org.apache.dolphinscheduler.plugin.task.api.parameters.ParametersNode;
-import org.apache.dolphinscheduler.plugin.task.api.parameters.resource.ResourceParametersHelper;
 
 public class SagemakerTaskChannel implements TaskChannel {
 
-    @Override
-    public void cancelApplication(boolean status) {
-
-    }
-
     @Override
     public SagemakerTask createTask(TaskExecutionContext taskRequest) {
         return new SagemakerTask(taskRequest);
     }
 
     @Override
-    public AbstractParameters parseParameters(ParametersNode parametersNode) {
-        return JSONUtils.parseObject(parametersNode.getTaskParams(), SagemakerParameters.class);
-    }
-
-    @Override
-    public ResourceParametersHelper getResources(String parameters) {
-        return JSONUtils.parseObject(parameters, SagemakerParameters.class).getResources();
+    public AbstractParameters parseParameters(String taskParams) {
+        return JSONUtils.parseObject(taskParams, SagemakerParameters.class);
     }
 
 }
