@@ -46,11 +46,14 @@ import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.ResultSetMetaData;
 import java.sql.SQLException;
+import java.sql.Statement;
 import java.util.ArrayList;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Optional;
+import java.util.Set;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import java.util.stream.Collectors;
@@ -81,12 +84,13 @@ public class SqlTask extends AbstractTask {
      */
     private static final int QUERY_LIMIT = 10000;
 
-    private SQLTaskExecutionContext sqlTaskExecutionContext;
-
-    public static final int TEST_FLAG_YES = 1;
+    private final SQLTaskExecutionContext sqlTaskExecutionContext;
 
     private final DbType dbType;
 
+    private Connection sessionConnection;
+    private Statement sessionStatement;
+
     public SqlTask(TaskExecutionContext taskRequest) {
         super(taskRequest);
         this.taskExecutionContext = taskRequest;
@@ -153,6 +157,10 @@ public class SqlTask extends AbstractTask {
             setExitStatusCode(TaskConstants.EXIT_CODE_SUCCESS);
 
         } catch (Exception e) {
+            if (exitStatusCode == TaskConstants.EXIT_CODE_KILL) {
+                log.info("sql task has been killed");
+                return;
+            }
             setExitStatusCode(TaskConstants.EXIT_CODE_FAILURE);
             log.error("sql task error", e);
             throw new TaskException("Execute sql task failed", e);
@@ -161,7 +169,14 @@ public class SqlTask extends AbstractTask {
 
     @Override
     public void cancel() throws TaskException {
-
+        try {
+            if (sessionStatement != null) {
+                sessionStatement.cancel();
+            }
+            exitStatusCode = TaskConstants.EXIT_CODE_KILL;
+        } catch (Exception e) {
+            throw new TaskException("Cancel sql task failed", e);
+        }
     }
 
     /**
@@ -178,7 +193,7 @@ public class SqlTask extends AbstractTask {
                 Connection connection =
                         DataSourceClientProvider.getAdHocConnection(DbType.valueOf(sqlParameters.getType()),
                                 baseConnectionParam)) {
-
+            sessionConnection = connection;
             // pre execute
             executeUpdate(connection, preStatementsBinds, "pre");
 
@@ -233,11 +248,23 @@ public class SqlTask extends AbstractTask {
         if (resultSet != null) {
             ResultSetMetaData md = resultSet.getMetaData();
             int num = md.getColumnCount();
+            String[] columnLabels = new String[num];
+
+            // Check for duplicates in column definitions (across all columns)
+            Set<String> uniqueLabels = new HashSet<>(num);
+            for (int i = 1; i <= num; i++) {
+                String label = md.getColumnLabel(i);
+                columnLabels[i - 1] = label;
+                if (!uniqueLabels.add(label)) {
+                    throw new TaskException("SQL column name conflict: duplicate column name '" + label
+                            + "'. Please use aliases to ensure unique column names.");
+                }
+            }
 
             while (resultSet.next()) {
                 ObjectNode mapOfColValues = JSONUtils.createObjectNode();
                 for (int i = 1; i <= num; i++) {
-                    mapOfColValues.set(md.getColumnLabel(i), JSONUtils.toJsonNode(resultSet.getObject(i)));
+                    mapOfColValues.set(columnLabels[i - 1], JSONUtils.toJsonNode(resultSet.getObject(i)));
                 }
                 resultJSONArray.add(mapOfColValues);
             }
@@ -311,8 +338,8 @@ public class SqlTask extends AbstractTask {
                                  String handlerType) throws Exception {
         int result = 0;
         for (SqlBinds sqlBind : statementsBinds) {
-            try (PreparedStatement statement = prepareStatementAndBind(connection, sqlBind)) {
-                result = statement.executeUpdate();
+            try (PreparedStatement tmpStatement = prepareStatementAndBind(connection, sqlBind)) {
+                result = tmpStatement.executeUpdate();
                 log.info("{} statement execute update result: {}, for sql: {}", handlerType, result,
                         sqlBind.getSql());
             }
@@ -320,21 +347,6 @@ public class SqlTask extends AbstractTask {
         return String.valueOf(result);
     }
 
-    /**
-     * close jdbc resource
-     *
-     * @param connection connection
-     */
-    private void close(Connection connection) {
-        if (connection != null) {
-            try {
-                connection.close();
-            } catch (SQLException e) {
-                log.error("close connection error : {}", e.getMessage(), e);
-            }
-        }
-    }
-
     /**
      * preparedStatement bind
      *
@@ -363,6 +375,7 @@ public class SqlTask extends AbstractTask {
             }
             log.info("prepare statement replace sql : {}, sql parameters : {}", sqlBinds.getSql(),
                     sqlBinds.getParamsMap());
+            sessionStatement = stmt;
             return stmt;
         } catch (Exception exception) {
             throw new TaskException("SQL task prepareStatementAndBind error", exception);
