@@ -29,7 +29,10 @@ export const COLUMN_WIDTH_CONFIG = {
     width: 50
   },
   linkName: {
-    width: 200
+    width: 200,
+    ellipsis: {
+      tooltip: true
+    }
   },
   linkEllipsis: {
     style: 'max-width: 180px;line-height: 1.5'
@@ -95,8 +98,14 @@ export const COLUMN_WIDTH_CONFIG = {
   tag: {
     width: 160
   },
+  checkbox: {
+    width: 20
+  },
   copy: {
-    width: 50
+    width: 35
+  },
+  instances: {
+    width: 40
   }
 }
 
