@@ -505,6 +505,29 @@ export default {
       'set the complement task thread to a reasonable value to avoid too large impact on the server.',
     task_manager_number: 'TaskManager Number',
     task_manager_number_tips: 'Please enter TaskManager number',
+    grpc_url: 'gRPC Url',
+    grpc_url_tips: 'Please Enter gRPC Url',
+    grpc_url_format_tips:
+      'Request address format is incorrect, gRPC only allows host:port format',
+    grpc_credential_type: 'gRPC Credential Type',
+    grpc_credential_type_insecure: 'Insecure',
+    grpc_credential_type_tls_default: 'Default client SSL/TLS',
+    grpc_method: 'gRPC Method',
+    grpc_method_tips:
+      'Please Enter gRPC Method (required, Service/Method), eg: Greeter/SayHello',
+    grpc_service_definition: 'Protobuf Definition',
+    grpc_service_definition_tips: 'Please Enter Protobuf Definition (required)',
+    grpc_service_definition_invalid: 'Invalid Protobuf Definition',
+    grpc_message: 'Message',
+    grpc_message_tips: 'Please Enter Message(JSON format)',
+    grpc_message_tips_invalid_json: 'Message is not in valid JSON format',
+    grpc_message_tips_not_correspond2proto:
+      'Message content does not conform to proto format',
+    grpc_check_condition: 'gRPC Check Condition',
+    grpc_status_code_default: 'Default status code OK',
+    grpc_status_code_custom: 'Custom status code',
+    grpc_condition: 'gRPC Condition',
+    grpc_condition_tips: 'Please Enter gRPC Condition',
     http_url: 'Http Url',
     http_url_tips: 'Please Enter Http Url',
     http_url_validator: 'The request address must contain HTTP or HTTPS',
@@ -863,18 +886,6 @@ export default {
     dinky_task_id: 'Dinky task id',
     dinky_task_id_tips: 'Please enter the task id of your dinky',
     dinky_online: 'Online task',
-    pytorch_script: 'Python Script',
-    pytorch_script_params: 'Script Input Parameters',
-    pytorch_other_params: 'Show More Configurations',
-    pytorch_python_path: 'Project Path',
-    pytorch_is_create_environment: 'Create An Environment Or Not',
-    pytorch_python_launcher: 'Python Executable Path',
-    pytorch_python_launcher_tips: 'If empty，will be set $PYTHON_LAUNCHER',
-    pytorch_python_env_tool: 'Python Environment Manager Tool',
-    pytorch_requirements: 'Requirement File',
-    pytorch_conda_python_version: 'Python Version',
-    pytorch_conda_python_version_tips:
-      'Please enter the version number, such as 3.6, 3.7, 3.x',
     factory_name: 'Factory Name',
     resource_group_name: 'Resource Group Name',
     pipeline_name: 'Pipeline Name',
