@@ -64,6 +64,7 @@ export default {
     group_name_tips: 'Please enter your group name',
     worker_addresses: 'Worker Addresses',
     worker_addresses_tips: 'Please select worker addresses',
+    source: 'Source',
     create_time: 'Create Time',
     update_time: 'Update Time'
   },
@@ -150,18 +151,14 @@ export default {
     project: 'Project',
     resource: 'Resource',
     file_resource: 'File Resource',
-    udf_resource: 'UDF Resource',
     datasource: 'Datasource',
-    udf: 'UDF Function',
     namespace: 'Namespace',
     revoke_auth: 'Revoke',
     grant_read: 'Grant Read',
     grant_all: 'Grant All',
     authorize_project: 'Project Authorize',
-    authorize_resource: 'Resource Authorize',
     authorize_namespace: 'Namespace Authorize',
     authorize_datasource: 'Datasource Authorize',
-    authorize_udf: 'UDF Function Authorize',
     username: 'Username',
     username_exists: 'The username already exists',
     username_tips: 'Please enter username',
@@ -205,8 +202,6 @@ export default {
     alarm_instance_name: 'Alarm instance name',
     alarm_instance_name_tips: 'Please enter alarm plugin instance name',
     alarm_plugin_name: 'Alarm plugin name',
-    alarm_instance_type: 'Alarm instance type',
-    is_global_instance: 'Is Global Instance',
     create_time: 'Create Time',
     update_time: 'Update Time',
     operation: 'Operation',
@@ -250,7 +245,7 @@ export default {
     requestType: 'Request Type',
     headerParams: 'Headers',
     bodyParams: 'Body',
-    contentField: 'Content Field',
+    contentType: 'Content Type',
     timeout: 'Timeout(s)',
     Keyword: 'Keyword',
     userParams: 'User Params',
@@ -269,7 +264,7 @@ export default {
     AtSomeoneInRoom: 'At Someone In Room',
     Destination: 'Destination',
     AtMobiles: 'At User Mobiles',
-    AtUserIds: 'At User Ids',
+    AtDingtalkIds: 'At User Ids',
     MsgType: 'Msg Type',
     // eslint-disable-next-line quotes
     IsAtAll: "{'@'}All",
