@@ -491,6 +491,26 @@ export default {
       '如果存在大量任务需要补数时,可以利用自定义并行度将补数的任务线程设置成合理的数值,避免对服务器造成过大的影响',
     task_manager_number: 'TaskManager数量',
     task_manager_number_tips: '请输入TaskManager数量',
+    grpc_url: '请求地址',
+    grpc_url_tips: '请输入请求地址(必填)',
+    grpc_url_format_tips: '请求地址格式不正确, gRPC仅允许host:port格式',
+    grpc_credential_type: 'gRPC 凭证类型',
+    grpc_credential_type_insecure: '不安全',
+    grpc_credential_type_tls_default: '客户端系统SSL/TLS',
+    grpc_method: '方法名称',
+    grpc_method_tips: '请输入方法名称(必填，服务/方法)，例如: Greeter/SayHello',
+    grpc_service_definition: 'Protobuf 定义',
+    grpc_service_definition_tips: '请输入Protobuf定义(必填)',
+    grpc_service_definition_invalid: '无效的Protobuf定义',
+    grpc_message: '消息内容',
+    grpc_message_tips: '请输入消息内容(JSON 格式)',
+    grpc_message_tips_invalid_json: '消息内容不是有效的JSON格式',
+    grpc_message_tips_not_correspond2proto: '消息内容不匹配Protobuf格式',
+    grpc_check_condition: '校验条件',
+    grpc_status_code_default: '默认状态码OK',
+    grpc_status_code_custom: '自定义状态码',
+    grpc_condition: '校验内容',
+    grpc_condition_tips: '请填写校验内容',
     http_url: '请求地址',
     http_url_tips: '请填写请求地址(必填)',
     http_url_validator: '请求地址需包含http或者https',
@@ -835,17 +855,6 @@ export default {
     dinky_task_id: 'dinky 作业ID',
     dinky_task_id_tips: '请输入作业 ID',
     dinky_online: '是否上线作业',
-    pytorch_script: 'python脚本',
-    pytorch_script_params: '脚本启动参数',
-    pytorch_other_params: '展开更多配置',
-    pytorch_python_path: 'python项目地址',
-    pytorch_is_create_environment: '是否创建新环境',
-    pytorch_python_launcher: 'python解释器路径',
-    pytorch_python_launcher_tips: '若为空，则使用$PYTHON_LAUNCHER',
-    pytorch_python_env_tool: 'python环境管理工具',
-    pytorch_requirements: '依赖文件',
-    pytorch_conda_python_version: 'python版本',
-    pytorch_conda_python_version_tips: '请输入版本号，如 3.6, 3.7, 3.x等',
     factory_name: '工厂名称',
     resource_group_name: '资源组名称',
     pipeline_name: 'pipeline名称',
