@@ -16,6 +16,7 @@
  */
 
 import { axios } from '@/service/service'
+import type { ServerNodeType } from './types'
 
 export function queryDatabaseState(): any {
   return axios({
@@ -37,3 +38,10 @@ export function listWorker(): any {
     method: 'get'
   })
 }
+
+export function listMonitorServerNode(nodeType: ServerNodeType): any {
+  return axios({
+    url: `/monitor/${nodeType}`,
+    method: 'get'
+  })
+}
