@@ -37,10 +37,6 @@ interface UserIdReq {
   userId?: number
 }
 
-interface UpdateProjectsReq extends ProjectsReq {
-  userName?: string
-}
-
 interface ProjectList {
   id: number
   userId: number
@@ -64,12 +60,4 @@ interface ProjectRes {
   start: number
 }
 
-export {
-  ListReq,
-  ListIdReq,
-  ProjectsReq,
-  UserIdReq,
-  UpdateProjectsReq,
-  ProjectRes,
-  ProjectList
-}
+export { ListReq, ListIdReq, ProjectsReq, UserIdReq, ProjectRes, ProjectList }
