@@ -20,14 +20,10 @@ interface FileReq {
 }
 
 interface ResourceTypeReq {
-  type: 'FILE' | 'UDF'
+  type: 'FILE'
   programType?: string
 }
 
-interface UdfTypeReq {
-  type: 'HIVE' | 'SPARK'
-}
-
 interface NameReq {
   name: string
 }
@@ -84,13 +80,6 @@ interface ViewResourceReq {
   skipLineNum: number
 }
 
-interface UdfFuncReq extends UdfTypeReq, DescriptionReq, FullNameReq {
-  className: string
-  funcName: string
-  argTypes?: string
-  database?: string
-}
-
 interface ResourceFile {
   id: number
   pid: number
@@ -122,7 +111,6 @@ interface ResourceViewRes {
 export {
   FileReq,
   ResourceTypeReq,
-  UdfTypeReq,
   NameReq,
   FileNameReq,
   FullNameReq,
@@ -136,7 +124,6 @@ export {
   ProgramTypeReq,
   ListReq,
   ViewResourceReq,
-  UdfFuncReq,
   ResourceListRes,
   ResourceViewRes,
   ResourceFile
