@@ -54,6 +54,9 @@ export const TASK_TYPES_MAP = {
   DEPENDENT: {
     alias: 'DEPENDENT'
   },
+  GRPC: {
+    alias: 'GRPC'
+  },
   HTTP: {
     alias: 'HTTP'
   },
@@ -123,10 +126,6 @@ export const TASK_TYPES_MAP = {
     helperLinkDisable: true,
     taskExecuteType: 'STREAM'
   },
-  PYTORCH: {
-    alias: 'Pytorch',
-    helperLinkDisable: true
-  },
   HIVECLI: {
     alias: 'HIVECLI',
     helperLinkDisable: true
