@@ -41,7 +41,10 @@ import { useLocalesStore } from '@/store/locales/locales'
 import { useThemeStore } from '@/store/theme/theme'
 import cookies from 'js-cookie'
 import { ssoLoginUrl } from '@/service/modules/login'
-import type { OAuth2Provider } from '@/service/modules/login/types'
+import type {
+  OAuth2Provider,
+  OidcProvider
+} from '@/service/modules/login/types'
 
 const login = defineComponent({
   name: 'login',
@@ -52,7 +55,9 @@ const login = defineComponent({
     const {
       handleLogin,
       handleGetOAuth2Provider,
+      handleGetOidcProviders,
       oauth2Providers,
+      oidcProviders,
       gotoOAuth2Page,
       handleRedirect
     } = useLogin(state)
@@ -86,6 +91,7 @@ const login = defineComponent({
     })
 
     handleGetOAuth2Provider()
+    handleGetOidcProviders()
     return {
       t,
       handleChange,
@@ -94,6 +100,7 @@ const login = defineComponent({
       localesStore,
       trim,
       oauth2Providers,
+      oidcProviders,
       gotoOAuth2Page
     }
   },
@@ -183,7 +190,8 @@ const login = defineComponent({
               </NButton>
             </a>
           </div>
-          {this.oauth2Providers.length > 0 && (
+          {(this.oauth2Providers.length > 0 ||
+            this.oidcProviders.length > 0) && (
             <NDivider>{this.t('login.loginWithOAuth2')}</NDivider>
           )}
 
@@ -199,6 +207,21 @@ const login = defineComponent({
                 </NButton>
               )
             })}
+            {this.oidcProviders?.map((e: OidcProvider) => {
+              const authUrl = `/dolphinscheduler/oauth2/authorization/${e.id}`
+              return (
+                <a href={authUrl} class={styles['oidc-provider-link']}>
+                  <NButton block class={styles['oidc-provider-btn']}>
+                    <div class={styles['oidc-btn-content']}>
+                      {e.iconUri && (
+                        <img src={e.iconUri} class={styles['oidc-btn-icon']} />
+                      )}
+                      <span>{e.displayName}</span>
+                    </div>
+                  </NButton>
+                </a>
+              )
+            })}
           </NSpace>
         </div>
       </div>
