@@ -16,11 +16,20 @@
  */
 
 import { useRouter, useRoute } from 'vue-router'
-import { clearCookie, getOauth2Provider, login } from '@/service/modules/login'
+import {
+  clearCookie,
+  getOauth2Provider,
+  getOidcProviders,
+  login
+} from '@/service/modules/login'
 import { getUserInfo } from '@/service/modules/users'
 import { useUserStore } from '@/store/user/user'
 import type { Router } from 'vue-router'
-import type { LoginRes, OAuth2Provider } from '@/service/modules/login/types'
+import type {
+  LoginRes,
+  OAuth2Provider,
+  OidcProvider
+} from '@/service/modules/login/types'
 import type { UserInfoRes } from '@/service/modules/users/types'
 import { useRouteStore } from '@/store/route/route'
 import { useTimezoneStore } from '@/store/timezone/timezone'
@@ -66,7 +75,14 @@ export function useLogin(state: any) {
     })
   }
 
+  const handleGetOidcProviders = () => {
+    getOidcProviders().then((res: Array<OidcProvider> | []) => {
+      oidcProviders.value = res
+    })
+  }
+
   const oauth2Providers = ref<Array<OAuth2Provider> | []>([])
+  const oidcProviders = ref<Array<OidcProvider> | []>([])
 
   const gotoOAuth2Page = async (oauth2Provider: OAuth2Provider) => {
     await clearCookie()
@@ -77,19 +93,21 @@ export function useLogin(state: any) {
 
   const handleRedirect = async () => {
     const authType = route.query.authType
-    if (authType && authType === 'oauth2') {
-      const sessionId = route.query.sessionId
-      if (sessionId) {
-        cookies.set('sessionId', String(sessionId), { path: '/' })
-        const userInfoRes: UserInfoRes = await getUserInfo()
-        await userStore.setUserInfo(userInfoRes)
-        const timezone = userInfoRes.timeZone ? userInfoRes.timeZone : 'UTC'
-        await timezoneStore.setTimezone(timezone)
-        router.push('home')
-      }
-      const error = route.query.error
-      if (error) {
-        window.$message.error(error)
+    if (authType) {
+      if (authType === 'oauth2' || authType === 'oidc') {
+        const sessionId = route.query.sessionId
+        if (sessionId) {
+          cookies.set('sessionId', String(sessionId), { path: '/' })
+          const userInfoRes: UserInfoRes = await getUserInfo()
+          await userStore.setUserInfo(userInfoRes)
+          const timezone = userInfoRes.timeZone ? userInfoRes.timeZone : 'UTC'
+          await timezoneStore.setTimezone(timezone)
+          router.push('home')
+        }
+        const error = route.query.error
+        if (error) {
+          window.$message.error(String(error))
+        }
       }
     }
   }
@@ -97,8 +115,10 @@ export function useLogin(state: any) {
   return {
     handleLogin,
     handleGetOAuth2Provider,
+    handleGetOidcProviders,
     gotoOAuth2Page,
     oauth2Providers,
+    oidcProviders,
     handleRedirect
   }
 }
