@@ -16,7 +16,7 @@
  */
 import { computed, watch, watchEffect } from 'vue'
 import { useI18n } from 'vue-i18n'
-import { useCustomParams, useMainJar, useResources } from '.'
+import { useCustomParams, useMainJar, useResources, useYarnQueue } from '.'
 import type { IJsonItem } from '../types'
 
 export function useFlink(model: { [field: string]: any }): IJsonItem[] {
@@ -53,6 +53,10 @@ export function useFlink(model: { [field: string]: any }): IJsonItem[] {
         {
           label: 'local',
           value: 'local'
+        },
+        {
+          label: 'standalone',
+          value: 'standalone'
         }
       ]
     }
@@ -98,7 +102,8 @@ export function useFlink(model: { [field: string]: any }): IJsonItem[] {
   )
 
   watchEffect(() => {
-    model.flinkVersion = model.programType === 'SQL' ? '>=1.13' : model.flinkVersion
+    model.flinkVersion =
+      model.programType === 'SQL' ? '>=1.13' : model.flinkVersion
   })
 
   return [
@@ -161,6 +166,9 @@ export function useFlink(model: { [field: string]: any }): IJsonItem[] {
       field: 'rawScript',
       span: scriptSpan,
       name: t('project.node.script'),
+      props: {
+        language: 'sql'
+      },
       validate: {
         trigger: ['input', 'trigger'],
         required: true,
@@ -274,6 +282,7 @@ export function useFlink(model: { [field: string]: any }): IJsonItem[] {
       },
       value: model.parallelism
     },
+    useYarnQueue(),
     {
       type: 'input',
       field: 'mainArgs',
