@@ -33,6 +33,10 @@ export function useKubeflow(model: { [field: string]: any }): IJsonItem[] {
         message: 'requestJson'
       }
     },
-    ...useCustomParams({ model, field: 'localParams', isSimple: false })
+    ...useCustomParams({
+      model,
+      field: 'localParams',
+      isSimple: model.readonly
+    })
   ]
 }
