@@ -24,6 +24,7 @@ export type TaskType =
   | 'MR'
   | 'PYTHON'
   | 'DEPENDENT'
+  | 'GRPC'
   | 'HTTP'
   | 'DATAX'
   | 'SQOOP'
@@ -42,7 +43,6 @@ export type TaskType =
   | 'SAGEMAKER'
   | 'CHUNJUN'
   | 'FLINK_STREAM'
-  | 'PYTORCH'
   | 'HIVECLI'
   | 'DMS'
   | 'DATASYNC'
@@ -86,6 +86,10 @@ export const TASK_TYPES_MAP = {
   DEPENDENT: {
     alias: 'DEPENDENT'
   },
+  GRPC: {
+    alias: 'GRPC',
+    helperLinkDisable: true
+  },
   HTTP: {
     alias: 'HTTP'
   },
@@ -151,10 +155,6 @@ export const TASK_TYPES_MAP = {
     helperLinkDisable: true,
     taskExecuteType: 'STREAM'
   },
-  PYTORCH: {
-    alias: 'Pytorch',
-    helperLinkDisable: true
-  },
   HIVECLI: {
     alias: 'HIVECLI',
     helperLinkDisable: true
