@@ -23,14 +23,7 @@ import {
   toRefs,
   watch
 } from 'vue'
-import {
-  NButton,
-  NInput,
-  NIcon,
-  NDataTable,
-  NPagination,
-  NSpace
-} from 'naive-ui'
+import { NButton, NIcon, NDataTable, NPagination, NSpace } from 'naive-ui'
 import DetailModal from './detail'
 import Card from '@/components/card'
 import { SearchOutlined } from '@vicons/antd'
@@ -39,6 +32,7 @@ import { useUserInfo } from './use-userinfo'
 import { useColumns } from './use-columns'
 import { useTable } from './use-table'
 import type { IRecord } from './types'
+import Search from '@/components/input-search'
 
 const AlarmInstanceManage = defineComponent({
   name: 'alarm-instance-manage',
@@ -129,13 +123,12 @@ const AlarmInstanceManage = defineComponent({
                   </NButton>
                 )}
                 <NSpace justify='end' wrap={false}>
-                  <NInput
-                    allowInput={this.trim}
-                    v-model={[this.searchVal, 'value']}
-                    size='small'
+                  <Search
+                    v-model:value={this.searchVal}
                     placeholder={`${t(
                       'security.alarm_instance.search_input_tips'
                     )}`}
+                    onSearch={onUpdatedList}
                   />
                   <NButton type='primary' size='small' onClick={onUpdatedList}>
                     <NIcon>
