@@ -24,10 +24,14 @@ import org.apache.dolphinscheduler.common.model.WorkerHeartBeat;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
 import org.apache.dolphinscheduler.common.utils.NetUtils;
 import org.apache.dolphinscheduler.common.utils.OSUtils;
+import org.apache.dolphinscheduler.meter.metrics.MetricsProvider;
+import org.apache.dolphinscheduler.meter.metrics.SystemMetrics;
 import org.apache.dolphinscheduler.registry.api.RegistryClient;
+import org.apache.dolphinscheduler.registry.api.utils.RegistryUtils;
 import org.apache.dolphinscheduler.server.worker.config.WorkerConfig;
-
-import java.util.function.Supplier;
+import org.apache.dolphinscheduler.server.worker.config.WorkerServerLoadProtection;
+import org.apache.dolphinscheduler.server.worker.metrics.WorkerServerMetrics;
+import org.apache.dolphinscheduler.task.executor.container.ITaskExecutorContainer;
 
 import lombok.NonNull;
 import lombok.extern.slf4j.Slf4j;
@@ -36,78 +40,76 @@ import lombok.extern.slf4j.Slf4j;
 public class WorkerHeartBeatTask extends BaseHeartBeatTask<WorkerHeartBeat> {
 
     private final WorkerConfig workerConfig;
+    private final WorkerServerLoadProtection workerServerLoadProtection;
     private final RegistryClient registryClient;
 
-    private final Supplier<Integer> workerWaitingTaskCount;
+    private final MetricsProvider metricsProvider;
 
     private final int processId;
 
+    private final ITaskExecutorContainer taskExecutorContainer;
+
     public WorkerHeartBeatTask(@NonNull WorkerConfig workerConfig,
+                               @NonNull WorkerServerLoadProtection workerServerLoadProtection,
+                               @NonNull MetricsProvider metricsProvider,
                                @NonNull RegistryClient registryClient,
-                               @NonNull Supplier<Integer> workerWaitingTaskCount) {
-        super("WorkerHeartBeatTask", workerConfig.getHeartbeatInterval().toMillis());
+                               @NonNull ITaskExecutorContainer taskExecutorContainer) {
+        super("WorkerHeartBeatTask", workerConfig.getMaxHeartbeatInterval().toMillis());
+        this.workerServerLoadProtection = workerServerLoadProtection;
+        this.metricsProvider = metricsProvider;
         this.workerConfig = workerConfig;
         this.registryClient = registryClient;
-        this.workerWaitingTaskCount = workerWaitingTaskCount;
+        this.taskExecutorContainer = taskExecutorContainer;
         this.processId = OSUtils.getProcessID();
     }
 
     @Override
     public WorkerHeartBeat getHeartBeat() {
-        double cpuUsagePercentage = OSUtils.cpuUsagePercentage();
-        int maxCpuUsePercentage = workerConfig.getMaxCpuLoadAvg();
-        double reservedMemory = workerConfig.getReservedMemory();
-        double memoryUsagePercentage = OSUtils.memoryUsagePercentage();
-        int execThreads = workerConfig.getExecThreads();
-        ServerStatus serverStatus =
-                getServerStatus(cpuUsagePercentage, maxCpuUsePercentage, memoryUsagePercentage, reservedMemory,
-                        execThreads, this.workerWaitingTaskCount.get());
+        SystemMetrics systemMetrics = metricsProvider.getSystemMetrics();
 
         return WorkerHeartBeat.builder()
                 .startupTime(ServerLifeCycleManager.getServerStartupTime())
                 .reportTime(System.currentTimeMillis())
-                .cpuUsage(cpuUsagePercentage)
-                .availablePhysicalMemorySize(OSUtils.availablePhysicalMemorySize())
-                .memoryUsage(OSUtils.memoryUsagePercentage())
-                .reservedMemory(reservedMemory)
-                .diskAvailable(OSUtils.diskAvailable())
+                .jvmCpuUsage(systemMetrics.getJvmCpuUsagePercentage())
+                .cpuUsage(systemMetrics.getSystemCpuUsagePercentage())
+                .jvmMemoryUsage(systemMetrics.getJvmMemoryUsedPercentage())
+                .jvmHeapUsed(systemMetrics.getJvmHeapUsed())
+                .jvmHeapMax(systemMetrics.getJvmHeapMax())
+                .jvmNonHeapUsed(systemMetrics.getJvmNonHeapUsed())
+                .jvmNonHeapMax(systemMetrics.getJvmNonHeapMax())
+                .memoryUsage(systemMetrics.getSystemMemoryUsedPercentage())
+                .diskUsage(systemMetrics.getDiskUsedPercentage())
                 .processId(processId)
                 .workerHostWeight(workerConfig.getHostWeight())
-                .workerWaitingTaskCount(this.workerWaitingTaskCount.get())
-                .workerExecThreadCount(workerConfig.getExecThreads())
-                .serverStatus(serverStatus)
+                .threadPoolUsage(taskExecutorContainer.slotUsage())
+                .serverStatus(
+                        workerServerLoadProtection.isOverload(systemMetrics) ? ServerStatus.BUSY : ServerStatus.NORMAL)
                 .host(NetUtils.getHost())
                 .port(workerConfig.getListenPort())
+                .workerGroup(workerConfig.getGroup())
                 .build();
     }
 
     @Override
-    public void writeHeartBeat(WorkerHeartBeat workerHeartBeat) {
+    public void writeHeartBeat(final WorkerHeartBeat workerHeartBeat) {
+        final String failoverNodePath = RegistryUtils.getFailoveredNodePath(workerHeartBeat);
+        if (registryClient.exists(failoverNodePath)) {
+            log.warn("The worker: {} is under {}, means it has been failover will close myself",
+                    workerHeartBeat,
+                    failoverNodePath);
+            registryClient
+                    .getStoppable()
+                    .stop("The worker exist: " + failoverNodePath + ", means it has been failover will close myself");
+            return;
+        }
         String workerHeartBeatJson = JSONUtils.toJsonString(workerHeartBeat);
         String workerRegistryPath = workerConfig.getWorkerRegistryPath();
         registryClient.persistEphemeral(workerRegistryPath, workerHeartBeatJson);
+        WorkerServerMetrics.incWorkerHeartbeatCount();
         log.debug(
                 "Success write worker group heartBeatInfo into registry, workerRegistryPath: {} workerHeartBeatInfo: {}",
-                workerRegistryPath, workerHeartBeatJson);
+                workerRegistryPath,
+                workerHeartBeatJson);
     }
 
-    private ServerStatus getServerStatus(double cpuUsagePercentage,
-                                         double maxCpuUsePercentage,
-                                         double memoryUsagePercentage,
-                                         double reservedMemory,
-                                         int workerExecThreadCount,
-                                         int workerWaitingTaskCount) {
-        if (cpuUsagePercentage > maxCpuUsePercentage || (1 - memoryUsagePercentage) < reservedMemory) {
-            log.warn(
-                    "current cpu load average {} is higher than {} or available memory {} is lower than {}",
-                    cpuUsagePercentage, maxCpuUsePercentage, 1 - memoryUsagePercentage, reservedMemory);
-            return ServerStatus.ABNORMAL;
-        } else if (workerWaitingTaskCount > workerExecThreadCount) {
-            log.warn("current waiting task count {} is large than worker thread count {}, worker is busy",
-                    workerWaitingTaskCount, workerExecThreadCount);
-            return ServerStatus.BUSY;
-        } else {
-            return ServerStatus.NORMAL;
-        }
-    }
 }
